@@ -619,7 +619,7 @@ void fillAddFunction()
     scilab_fill_add(Bool, UInt32, M_M, Bool, UInt32, UInt32);
     scilab_fill_add(Bool, Int64, M_M, Bool, Int64, Int64);
     scilab_fill_add(Bool, UInt64, M_M, Bool, UInt64, UInt64);
-    scilab_fill_add(Bool, Bool, M_M, Bool, Bool, Bool);
+    scilab_fill_add(Bool, Bool, M_M, Bool, Bool, Double);
     scilab_fill_add(Bool, Empty, M_E, Bool, Double, Double);
 
     //Matrix + Scalar
@@ -632,7 +632,7 @@ void fillAddFunction()
     scilab_fill_add(Bool, ScalarUInt32, M_S, Bool, UInt32, UInt32);
     scilab_fill_add(Bool, ScalarInt64, M_S, Bool, Int64, Int64);
     scilab_fill_add(Bool, ScalarUInt64, M_S, Bool, UInt64, UInt64);
-    scilab_fill_add(Bool, ScalarBool, M_S, Bool, Bool, Bool);
+    scilab_fill_add(Bool, ScalarBool, M_S, Bool, Bool, Double);
 
     //Scalar + Matrix
     scilab_fill_add(ScalarBool, Double, S_M, Bool, Double, Double);
@@ -644,7 +644,7 @@ void fillAddFunction()
     scilab_fill_add(ScalarBool, UInt32, S_M, Bool, UInt32, UInt32);
     scilab_fill_add(ScalarBool, Int64, S_M, Bool, Int64, Int64);
     scilab_fill_add(ScalarBool, UInt64, S_M, Bool, UInt64, UInt64);
-    scilab_fill_add(ScalarBool, Bool, S_M, Bool, Bool, Bool);
+    scilab_fill_add(ScalarBool, Bool, S_M, Bool, Bool, Double);
     scilab_fill_add(ScalarBool, Empty, S_E, Bool, Double, Double);
 
     //Scalar + Scalar
@@ -657,7 +657,7 @@ void fillAddFunction()
     scilab_fill_add(ScalarBool, ScalarUInt32, S_S, Bool, UInt32, UInt32);
     scilab_fill_add(ScalarBool, ScalarInt64, S_S, Bool, Int64, Int64);
     scilab_fill_add(ScalarBool, ScalarUInt64, S_S, Bool, UInt64, UInt64);
-    scilab_fill_add(ScalarBool, ScalarBool, S_S, Bool, Bool, Bool);
+    scilab_fill_add(ScalarBool, ScalarBool, S_S, Bool, Bool, Double);
 
     //String
     scilab_fill_add(String, String, M_M, String, String, String);
@@ -795,6 +795,25 @@ void fillAddFunction()
 #undef scilab_fill_add
 }
 
+
+types::InternalType* GenericUnaryPlus(types::InternalType* _pL)
+{
+    /*
+    ** Convention: unary plus has a sense and returns operanf unchanged 
+    ** if operand is not a string and if binary plus with same operand is defined
+    */
+    add_function add = pAddfunction[_pL->getId()][_pL->getId()];
+    
+    if (!_pL->isString() && add != NULL)
+    {
+        return _pL;        
+    }
+    else
+    {
+        return NULL;
+    }
+}
+
 InternalType *GenericPlus(InternalType *_pLeftOperand, InternalType *_pRightOperand)
 {
     InternalType *pResult = NULL;
@@ -1808,12 +1827,13 @@ template<> InternalType* add_M_M<Polynom, Polynom, Polynom>(Polynom* _pL, Polyno
     Polynom* pRSave = _pR;
 
     Polynom* pOut = NULL;
+
+
+    //check varname
     if (_pL->getVariableName() != _pR->getVariableName())
     {
-        std::wostringstream os;
-        os << _W("variables don't have the same formal variable");
-        //os << ((Location)e.right_get().getLocation()).getLocationString() << std::endl;
-        throw ast::InternalError(os.str());
+        //call overload
+        return NULL;
     }
 
     if (_pR->isIdentity())
@@ -1942,6 +1962,11 @@ template<> InternalType* add_M_M<Polynom, Polynom, Polynom>(Polynom* _pL, Polyno
             _pR->killMe();
         }
 
+        if (pOut != NULL)
+        {
+            pOut->updateRank();
+        }
+
         return pOut;
     }
 
@@ -2023,6 +2048,11 @@ template<> InternalType* add_M_M<Polynom, Polynom, Polynom>(Polynom* _pL, Polyno
             _pR->killMe();
         }
 
+        if (pOut != NULL)
+        {
+            pOut->updateRank();
+        }
+
         return pOut;
     }
 
