@@ -15,6 +15,7 @@
 
 #include "types_power.hxx"
 #include "types_multiplication.hxx"
+#include "types_finite.hxx"
 
 extern "C"
 {
@@ -63,7 +64,7 @@ InternalType *GenericPower(InternalType *_pLeftOperand, InternalType *_pRightOpe
             case 1 :
                 throw ast::InternalError(_W("Inconsistent row/column dimensions.\n"));
             case 2 :
-                throw ast::InternalError(_W("Invalid exponent: expected real exponents.\n"));
+                throw ast::InternalError(_W("Invalid exponent: expected finite integer exponents.\n"));
             default:
                 //OK
                 break;
@@ -134,7 +135,7 @@ InternalType *GenericDotPower(InternalType *_pLeftOperand, InternalType *_pRight
             case 1 :
                 throw ast::InternalError(_W("Inconsistent row/column dimensions.\n"));
             case 2 :
-                throw ast::InternalError(_W("Invalid exponent: expected real exponents.\n"));
+                throw ast::InternalError(_W("Invalid exponent: expected finite integer exponents.\n"));
             default:
                 //OK
                 break;
@@ -158,6 +159,12 @@ int PowerDoubleByDouble(Double* _pDouble1, Double* _pDouble2, Double** _pDoubleO
 
     int iComplex = 1;
 
+    if (_pDouble1->isEmpty() || _pDouble2->isEmpty())
+    {
+        *_pDoubleOut = Double::Empty();
+        return 0;
+    }
+
     if (bScalar1)
     {
         if (bScalar2)
@@ -344,6 +351,11 @@ int PowerPolyByDouble(Polynom* _pPoly, Double* _pDouble, InternalType** _pOut)
     double* bImg    = _pDouble->getImg();
     bool bNumericallyComplex1 = _pDouble->isNumericallyComplex();
 
+    if (!isDoubleFinite(_pDouble))
+    {
+        return 2;
+    }
+
     if (!bNumericallyComplex1)
     {
         return 2;
@@ -366,6 +378,12 @@ int PowerPolyByDouble(Polynom* _pPoly, Double* _pDouble, InternalType** _pOut)
         for (int i = 0 ; i < _pDouble->getSize() ; i++)
         {
             int iInputRank = (int)_pDouble->get(i);
+            if ((double)iInputRank != _pDouble->get(i))
+            {
+                _pOut = NULL;
+                delete[] piRank;
+                return 2;
+            }
             if (iInputRank < 0)
             {
                 //call overload
@@ -614,7 +632,7 @@ int DotPowerPolyByDouble(Polynom* _pPoly, Double* _pDouble, InternalType** _pOut
         SinglePoly** pSPTempOut = pITTempOut->getAs<Polynom>()->get();
         pSPOut[i] = pSPTempOut[0];
         // increase ref to avoid the delete of pSPTempOut[0]
-        // which are setted in pSPOut without copy.
+        // which are set in pSPOut without copy.
         pSPOut[i]->IncreaseRef();
         delete pITTempOut;
         pSPOut[i]->DecreaseRef();
@@ -629,7 +647,7 @@ int DotPowerPolyByDouble(Polynom* _pPoly, Double* _pDouble, InternalType** _pOut
     delete[] pDblPower;
 
     // delete temporary polynom
-    // do not delete the last SinglePoly of _pPoly setted without copy in pPolyTemp
+    // do not delete the last SinglePoly of _pPoly set without copy in pPolyTemp
     pSPTemp[0]->IncreaseRef();
     delete pPolyTemp;
     pSP[iSize - 1]->DecreaseRef();
