@@ -285,9 +285,20 @@ bool getScalarImplicitIndex(GenericType* _pRef, typed_list* _pArgsIn, std::vecto
     {
         ImplicitList* pIL = pIT->getAs<ImplicitList>();
         int sizeRef = _pRef->getSize();
-        index.push_back(evalute(pIL->getStart(), sizeRef));
-        index.push_back(evalute(pIL->getStep(), sizeRef));
-        index.push_back(evalute(pIL->getEnd(), sizeRef));
+        double start = evalute(pIL->getStart(), sizeRef);
+        double step = evalute(pIL->getStep(), sizeRef);
+        double end = evalute(pIL->getEnd(), sizeRef);
+
+        if ((start < 1 && step > 0) || (end < 1 & step < 0))
+        {
+            wchar_t szError[bsiz];
+            os_swprintf(szError, bsiz, _W("Invalid index.\n").c_str());
+            throw ast::InternalError(szError);
+        }
+
+        index.push_back(start);
+        index.push_back(step);
+        index.push_back(end);
     }
 
     return true;
@@ -376,6 +387,13 @@ bool getImplicitIndex(GenericType* _pRef, typed_list* _pArgsIn, std::vector<int>
 
                 std::vector<int> idx(size);
 
+                if ((start < 1 && step > 0) || (end < 1 & step < 0))
+                {
+                    wchar_t szError[bsiz];
+                    os_swprintf(szError, bsiz, _W("Invalid index.\n").c_str());
+                    throw ast::InternalError(szError);
+                }
+
                 double val = start - 1;
                 std::generate(idx.begin(), idx.end(), [&val, step]{ double s = val; val += step; return (int)s; });
 
@@ -511,9 +529,10 @@ int checkIndexesArguments(InternalType* _pRef, typed_list* _pArgsIn, typed_list*
             {
                 int size = pCurrentArg->getSize();
                 double* dbl = pCurrentArg->get();
+                double minIndex = _pRef==NULL || _pRef->isList()==false ? 1 : 0;
                 for (int j = 0; j < size; ++j)
                 {
-                    if (dbl[j] < 0)
+                    if (dbl[j] < minIndex)
                     {
                         if (pCurrentArg->isDeletable())
                         {
@@ -536,54 +555,71 @@ int checkIndexesArguments(InternalType* _pRef, typed_list* _pArgsIn, typed_list*
                 //: or $
                 if (_pRef == NULL)
                 {
-                    //not enough information to compute indexes.
-                    _pArgsOut->push_back(NULL);
-                    bUndefine = true;
-                    pIL->killMe();
-                    continue;
-                }
-                //evalute polynom with "MaxDim"
-                int iMaxDim = _pRef->getAs<GenericType>()->getVarMaxDim(i, iDims);
-#if defined(_SCILAB_DEBUGREF_)
-                Double* pdbl = new Double(iMaxDim);
-#else
-                Double dbl(iMaxDim);
-#endif
-                if (pIL->getStart()->isPoly())
-                {
-                    Polynom *poPoly = pIL->getStart()->getAs<types::Polynom>();
-#if defined(_SCILAB_DEBUGREF_)
-                    pIL->setStart(poPoly->evaluate(pdbl));
-#else
-                    pIL->setStart(poPoly->evaluate(&dbl));
-#endif
-                }
-                if (pIL->getStep()->isPoly())
-                {
-                    Polynom *poPoly = pIL->getStep()->getAs<types::Polynom>();
-#if defined(_SCILAB_DEBUGREF_)
-                    pIL->setStep(poPoly->evaluate(pdbl));
-#else
-                    pIL->setStep(poPoly->evaluate(&dbl));
-#endif
-                }
-                if (pIL->getEnd()->isPoly())
-                {
-                    Polynom *poPoly = pIL->getEnd()->getAs<types::Polynom>();
-#if defined(_SCILAB_DEBUGREF_)
-                    pIL->setEnd(poPoly->evaluate(pdbl));
-#else
-                    pIL->setEnd(poPoly->evaluate(&dbl));
-#endif
+                    if (pIL->getStep()->isDouble() &&
+                        ((getIndex(pIL->getStep()) > 0 && pIL->getStart()->isDouble() && getIndex(pIL->getStart()) < 1) ||
+                        (getIndex(pIL->getStep()) < 0 && pIL->getEnd()->isDouble() && getIndex(pIL->getEnd()) < 1)))
+                    {
+                        pCurrentArg = NULL;
+                    }
+                    else
+                    {
+                        //not enough information to compute indexes.
+                        _pArgsOut->push_back(NULL);
+                        bUndefine = true;
+                        pIL->killMe();
+                        continue;
+                    }
                 }
+                else
+                {        //evalute polynom with "MaxDim"
+                    int iMaxDim = _pRef->getAs<GenericType>()->getVarMaxDim(i, iDims);
+    #if defined(_SCILAB_DEBUGREF_)
+                    Double* pdbl = new Double(iMaxDim);
+    #else
+                    Double dbl(iMaxDim);
+    #endif
+                    if (pIL->getStart()->isPoly())
+                    {
+                        Polynom *poPoly = pIL->getStart()->getAs<types::Polynom>();
+    #if defined(_SCILAB_DEBUGREF_)
+                        pIL->setStart(poPoly->evaluate(pdbl));
+    #else
+                        pIL->setStart(poPoly->evaluate(&dbl));
+    #endif
+                    }
+                    if (pIL->getStep()->isPoly())
+                    {
+                        Polynom *poPoly = pIL->getStep()->getAs<types::Polynom>();
+    #if defined(_SCILAB_DEBUGREF_)
+                        pIL->setStep(poPoly->evaluate(pdbl));
+    #else
+                        pIL->setStep(poPoly->evaluate(&dbl));
+    #endif
+                    }
+                    if (pIL->getEnd()->isPoly())
+                    {
+                        Polynom *poPoly = pIL->getEnd()->getAs<types::Polynom>();
+    #if defined(_SCILAB_DEBUGREF_)
+                        pIL->setEnd(poPoly->evaluate(pdbl));
+    #else
+                        pIL->setEnd(poPoly->evaluate(&dbl));
+    #endif
+                    }
 
-#if defined(_SCILAB_DEBUGREF_)
-                pdbl->killMe();
+    #if defined(_SCILAB_DEBUGREF_)
+                    pdbl->killMe();
 #endif
+                }
+            }
+            if (_pRef != NULL || pIL->isComputable() == true)
+            {
+                double start = getIndex(pIL->getStart());
+                double step = getIndex(pIL->getStep());
+                double end = getIndex(pIL->getEnd());
+
+                pCurrentArg = ((start < 1 && step > 0) || (end < 1 & step < 0)) ? NULL : pIL->extractFullMatrix()->getAs<Double>();
             }
 
-
-            pCurrentArg = pIL->extractFullMatrix()->getAs<Double>();
             pIL->killMe();
         }
         else if (pIT->isString())
@@ -694,6 +730,26 @@ int checkIndexesArguments(InternalType* _pRef, typed_list* _pArgsIn, typed_list*
             }
             pCurrentArg = pDbl;
         }
+        else if (pIT->isSparseBool())
+        {
+            types::SparseBool* pSb = pIT->getAs<types::SparseBool>();
+            int iItemCount = static_cast<int>(pSb->nbTrue());
+            int iRows = pSb->getRows();
+            int *pCoord = new int[iItemCount * 2];
+
+            //get (r,c) positions of True Elements
+            pSb->outputRowCol(pCoord);
+            int* pY = pCoord + iItemCount;
+            //allow new Double index variable
+            Double* pDbl = new Double(1, iItemCount);
+            double* pdbl = pDbl->getReal();
+            for (int i = 0; i < iItemCount; ++i)
+            {
+                pdbl[i] = pCoord[i] + (pY[i] - 1) * iRows;
+            }
+
+            pCurrentArg = pDbl;
+        }
         else if (pIT->isInt())
         {
             switch (pIT->getType())
@@ -873,7 +929,7 @@ int getIndexWithDims(int* _piIndexes, const int* _piDims, int _iDims)
 
 types::Function::ReturnValue VariableToString(types::InternalType* pIT, const wchar_t* wcsVarName)
 {
-    if (pIT->hasToString() == false)
+    if (pIT->hasToString() == false || pIT->isStruct())
     {
         types::Function::ReturnValue ret = types::Function::Error;
         //call overload %type_p
