@@ -1043,7 +1043,7 @@ types::Function::ReturnValue sci_ode(types::typed_list &in, int _iRetCount, type
 
     if (bOneStep)
     {
-        std::list<double*> pDblYOutList = std::list<double*>();
+        std::list<std::vector<double>> pDblYOutList = std::list<std::vector<double>>();
         std::list<double> pDblTOutList = std::list<double>();
         int iLastT = pDblT->getSize() - 1;
         double t = pDblT->get(iLastT);
@@ -1149,7 +1149,7 @@ types::Function::ReturnValue sci_ode(types::typed_list &in, int _iRetCount, type
                 {
                     wchar_t szError[bsiz];
                     wchar_t* tmp = to_wide_string(strMeth.c_str());
-                    os_swprintf(szError, bsiz, _W("%ls: An error occured in '%ls' subroutine.\n").c_str(), L"ode", tmp);
+                    os_swprintf(szError, bsiz, _W("%ls: An error occurred in '%ls' subroutine.\n").c_str(), L"ode", tmp);
                     os << szError;
                     FREE(tmp);
                     throw ast::InternalError(os.str());
@@ -1158,7 +1158,8 @@ types::Function::ReturnValue sci_ode(types::typed_list &in, int _iRetCount, type
                 return types::Function::Error;
             }
 
-            pDblYOutList.push_back(pdYData);
+            std::vector<double> newY (pdYData, pdYData + pDblY0->getSize());
+            pDblYOutList.push_back(newY);
             pDblTOutList.push_back(t0);
 
             if (err == 2) // warning case
@@ -1373,7 +1374,7 @@ types::Function::ReturnValue sci_ode(types::typed_list &in, int _iRetCount, type
                 {
                     wchar_t szError[bsiz];
                     wchar_t* tmp = to_wide_string(strMeth.c_str());
-                    os_swprintf(szError, bsiz, _W("%ls: An error occured in '%ls' subroutine.\n").c_str(), L"ode", tmp);
+                    os_swprintf(szError, bsiz, _W("%ls: An error occurred in '%ls' subroutine.\n").c_str(), L"ode", tmp);
                     os << szError;
                     FREE(tmp);
                     throw ast::InternalError(os.str());
@@ -1601,4 +1602,3 @@ types::Function::ReturnValue sci_ode(types::typed_list &in, int _iRetCount, type
 
     return types::Function::OK;
 }
-
