@@ -2,11 +2,14 @@
  *  Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  *  Copyright (C) 2011 - DIGITEO - Manuel Juliachs
  *
- *  This file must be used under the terms of the CeCILL.
- *  This source file is licensed as described in the file COPYING, which
- *  you should have received as part of this distribution.  The terms
- *  are also available at
- *  http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
+ * Copyright (C) 2012 - 2016 - Scilab Enterprises
+ *
+ * This file is hereby licensed under the terms of the GNU GPL v2.0,
+ * pursuant to article 5.3.4 of the CeCILL v.2.1.
+ * This file was originally licensed under the terms of the CeCILL v2.1,
+ * and continues to be available under such terms.
+ * For more information, see the COPYING file which you should have received
+ * along with this program.
  *
  */
 
@@ -14,6 +17,7 @@
 #include "ColorComputer.hxx"
 #include "Fac3DColorComputer.hxx"
 #include "Fac3DDecomposer.hxx"
+#include "Triangulator.hxx"
 
 extern "C"
 {
@@ -24,7 +28,7 @@ extern "C"
 #include "graphicObjectProperties.h"
 }
 
-int Fac3DDecomposer::getDataSize(char* id)
+int Fac3DDecomposer::getDataSize(int id)
 {
     int numVerticesPerGon = 0;
     int* piNumVerticesPerGon = &numVerticesPerGon;
@@ -34,10 +38,10 @@ int Fac3DDecomposer::getDataSize(char* id)
     getGraphicObjectProperty(id, __GO_DATA_MODEL_NUM_VERTICES_PER_GON__, jni_int, (void**) &piNumVerticesPerGon);
     getGraphicObjectProperty(id, __GO_DATA_MODEL_NUM_GONS__, jni_int, (void**) &piNumGons);
 
-    return numVerticesPerGon*numGons;
+    return numVerticesPerGon * numGons;
 }
 
-void Fac3DDecomposer::fillVertices(char* id, float* buffer, int bufferLength, int elementsSize, int coordinateMask, double* scale, double* translation, int logMask)
+void Fac3DDecomposer::fillVertices(int id, float* buffer, int bufferLength, int elementsSize, int coordinateMask, double* scale, double* translation, int logMask)
 {
     double* x = NULL;
     double* y = NULL;
@@ -60,7 +64,7 @@ void Fac3DDecomposer::fillVertices(char* id, float* buffer, int bufferLength, in
     getGraphicObjectProperty(id, __GO_DATA_MODEL_Z__, jni_int, (void**) &z);
 
 
-    for (i = 0; i < numVerticesPerGon*numGons; i++)
+    for (i = 0; i < numVerticesPerGon * numGons; i++)
     {
         if (coordinateMask & 0x1)
         {
@@ -102,10 +106,12 @@ void Fac3DDecomposer::fillVertices(char* id, float* buffer, int bufferLength, in
 
 }
 
-void Fac3DDecomposer::fillTextureCoordinates(char* id, float* buffer, int bufferLength)
+void Fac3DDecomposer::fillTextureCoordinates(int id, float* buffer, int bufferLength)
 {
-    char* parentFigure = NULL;
-    char* parent = NULL;
+    int parentFigure = 0;
+    int* pparentFigure = &parentFigure;
+    int parent = 0;
+    int* pparent = &parent;
 
     double* colors = NULL;
     double* colormap = NULL;
@@ -138,17 +144,18 @@ void Fac3DDecomposer::fillTextureCoordinates(char* id, float* buffer, int buffer
     getGraphicObjectProperty(id, __GO_DATA_MODEL_NUM_COLORS__, jni_int, (void**) &piNumColors);
     getGraphicObjectProperty(id, __GO_DATA_MODEL_COLORS__, jni_double_vector, (void**) &colors);
 
-    getGraphicObjectProperty(id, __GO_PARENT__, jni_string, (void**) &parent);
+
+    parent = getParentObject(id);
 
     /* Temporary: to avoid getting a null parent_figure property when the object is built */
-    if (strcmp(parent, "") == 0)
+    if (parent == 0)
     {
         return;
     }
 
-    getGraphicObjectProperty(id, __GO_PARENT_FIGURE__, jni_string, (void**) &parentFigure);
+    getGraphicObjectProperty(id, __GO_PARENT_FIGURE__, jni_int, (void**) &pparentFigure);
 
-    if (parentFigure == NULL)
+    if (parentFigure == 0)
     {
         return;
     }
@@ -165,7 +172,7 @@ void Fac3DDecomposer::fillTextureCoordinates(char* id, float* buffer, int buffer
     getGraphicObjectProperty(parentFigure, __GO_COLORMAP__, jni_double_vector, (void**) &colormap);
     getGraphicObjectProperty(parentFigure, __GO_COLORMAP_SIZE__, jni_int, (void**) &piColormapSize);
 
-    if (numColors == numGons*numVerticesPerGon)
+    if (numColors == numGons * numVerticesPerGon)
     {
         perVertex = 1;
     }
@@ -208,7 +215,7 @@ void Fac3DDecomposer::fillTextureCoordinates(char* id, float* buffer, int buffer
 }
 
 void Fac3DDecomposer::fillNormalizedZColorsTextureCoordinates(float* buffer, int bufferLength, double* colormap, int colormapSize,
-                                                              double* z, int numGons, int numVerticesPerGon)
+        double* z, int numGons, int numVerticesPerGon)
 {
     double zavg = 0.;
     double zMin = 0.;
@@ -221,7 +228,7 @@ void Fac3DDecomposer::fillNormalizedZColorsTextureCoordinates(float* buffer, int
     int j = 0;
     int bufferOffset = 0;
 
-    computeMinMaxValues(z, numGons*numVerticesPerGon, numGons, numVerticesPerGon, ALL_VALUES, &zMin, &zMax);
+    computeMinMaxValues(z, numGons * numVerticesPerGon, numGons, numVerticesPerGon, ALL_VALUES, &zMin, &zMax);
 
     minDoubleValue = DecompositionUtils::getMinDoubleValue();
 
@@ -238,7 +245,7 @@ void Fac3DDecomposer::fillNormalizedZColorsTextureCoordinates(float* buffer, int
     for (i = 0; i < numGons; i++)
     {
         /* Per-face average */
-        zavg = computeAverageValue(&z[i*numVerticesPerGon], numVerticesPerGon);
+        zavg = computeAverageValue(&z[i * numVerticesPerGon], numVerticesPerGon);
         index = (float)((ColorComputer::getIndex(zavg, zMin, zRange, Z_COLOR_OFFSET, 0, colormapSize - 1) + 2.0 + COLOR_TEXTURE_OFFSET) / (float) (colormapSize + 2));
 
         for (j = 0; j < numVerticesPerGon; j++)
@@ -253,13 +260,13 @@ void Fac3DDecomposer::fillNormalizedZColorsTextureCoordinates(float* buffer, int
 }
 
 void Fac3DDecomposer::fillConstantColorsTextureCoordinates(float* buffer, int bufferLength, double* colormap, int colormapSize,
-                                                           double colorValue, int numGons, int numVerticesPerGon)
+        double colorValue, int numGons, int numVerticesPerGon)
 {
     int bufferOffset = 0;
 
     double index = (ColorComputer::getClampedDirectIndex(colorValue - 1.0, colormapSize) + 2.0 + COLOR_TEXTURE_OFFSET) / (float) (colormapSize + 2);
 
-    for (int i = 0; i < numGons*numVerticesPerGon; i++)
+    for (int i = 0; i < numGons * numVerticesPerGon; i++)
     {
         buffer[bufferOffset++] = (float)index;
         buffer[bufferOffset++] = 0;
@@ -270,7 +277,7 @@ void Fac3DDecomposer::fillConstantColorsTextureCoordinates(float* buffer, int bu
 }
 
 void Fac3DDecomposer::fillDataColorsTextureCoordinates(float* buffer, int bufferLength, double* colormap, int colormapSize,
-                                                       double* colors, int colorFlag, int perVertex, int dataMapping, int numGons, int numVerticesPerGon)
+        double* colors, int colorFlag, int perVertex, int dataMapping, int numGons, int numVerticesPerGon)
 {
     double colMin = 0.;
     double colRange = 0.;
@@ -286,7 +293,7 @@ void Fac3DDecomposer::fillDataColorsTextureCoordinates(float* buffer, int buffer
 
     if (perVertex)
     {
-        numColors = numGons*numVerticesPerGon;
+        numColors = numGons * numVerticesPerGon;
     }
     else
     {
@@ -321,7 +328,7 @@ void Fac3DDecomposer::fillDataColorsTextureCoordinates(float* buffer, int buffer
             }
             else if (dataMapping == 0)
             {
-                index = ColorComputer::getIndex(color, colMin, colRange, COLOR_OFFSET, 0, colormapSize-1);
+                index = ColorComputer::getIndex(color, colMin, colRange, COLOR_OFFSET, 0, colormapSize - 1);
             }
 
             /* The offset corresponding to the black and white colors must added to the index and the colormap size. */
@@ -348,7 +355,7 @@ double Fac3DDecomposer::computeAverageValue(double* values, int numVertices)
 }
 
 void Fac3DDecomposer::computeMinMaxValues(double* values, int numValues, int numGons, int numVerticesPerGon, int minMaxComputation,
-                                          double* valueMin, double* valueMax)
+        double* valueMin, double* valueMax)
 {
     double maxDouble = DecompositionUtils::getMaxDoubleValue();
     double tmpValueMin = maxDouble;
@@ -370,11 +377,11 @@ void Fac3DDecomposer::computeMinMaxValues(double* values, int numValues, int num
     {
         if (minMaxComputation == FIRST_VERTEX_VALUE)
         {
-            value = values[i*numVerticesPerGon];
+            value = values[i * numVerticesPerGon];
         }
         else if (minMaxComputation == FACE_AVERAGE)
         {
-            value = computeAverageValue(&values[i*numVerticesPerGon], numVerticesPerGon);
+            value = computeAverageValue(&values[i * numVerticesPerGon], numVerticesPerGon);
         }
         else
         {
@@ -399,7 +406,7 @@ void Fac3DDecomposer::computeMinMaxValues(double* values, int numValues, int num
     *valueMax = tmpValueMax;
 }
 
-int Fac3DDecomposer::getIndicesSize(char* id)
+int Fac3DDecomposer::getIndicesSize(int id)
 {
     int numVerticesPerGon = 0;
     int* piNumVerticesPerGon = &numVerticesPerGon;
@@ -414,14 +421,14 @@ int Fac3DDecomposer::getIndicesSize(char* id)
         return 0;
     }
 
-    return 3*(numVerticesPerGon-2)*numGons;
+    return 3 * (numVerticesPerGon - 2) * numGons;
 }
 
 /*
  * To do: use a polygon triangulation algorithm, as the fan decomposition used may produce
  * overlapping triangles for non-convex polygons.
  */
-int Fac3DDecomposer::fillIndices(char* id, int* buffer, int bufferLength, int logMask)
+int Fac3DDecomposer::fillIndices(int id, int* buffer, int bufferLength, int logMask)
 {
     double* x = NULL;
     double* y = NULL;
@@ -477,18 +484,20 @@ int Fac3DDecomposer::fillIndices(char* id, int* buffer, int bufferLength, int lo
     for (int i = 0; i < numGons; i++)
     {
         int isValid = 1;
+        Triangulator triangulator;
 
         for (int j = 0; j < numVerticesPerGon; j++)
         {
-            xc = x[vertexOffset+j];
-            yc = y[vertexOffset+j];
-            zc = z[vertexOffset+j];
+            xc = x[vertexOffset + j];
+            yc = y[vertexOffset + j];
+            zc = z[vertexOffset + j];
 
             if (!DecompositionUtils::isValid(xc, yc, zc) || !DecompositionUtils::isLogValid(xc, yc, zc, logMask))
             {
                 isValid = 0;
                 break;
             }
+            triangulator.addPoint(xc, yc, zc);
         }
 
         if (isValid == 0 || colorComputer.isFacetColorValid(i) == 0)
@@ -497,15 +506,29 @@ int Fac3DDecomposer::fillIndices(char* id, int* buffer, int bufferLength, int lo
             continue;
         }
 
-        /* Performs a fan decomposition, vertices are ordered counter-clockwise. */
-        for (int j = 0; j < numVerticesPerGon-2; j++)
+        triangulator.initialize();
+        triangulator.triangulate();
+        int numTriangles = triangulator.getNumberTriangles();
+
+        //Failed to triangulate, should not happen, unless the points are colinear
+        if (numTriangles < 1)
         {
-            buffer[bufferOffset] = vertexOffset;
-            buffer[bufferOffset +1] = vertexOffset + j+2;
-            buffer[bufferOffset +2] = vertexOffset + j+1;
+            vertexOffset += numVerticesPerGon;
+            continue;
+        }
+
+        int * indices = triangulator.getIndices();
+
+
+        for (int j = 0; j < numTriangles; j++)
+        {
+            buffer[bufferOffset] = vertexOffset + indices[3 * j];
+            buffer[bufferOffset + 1] = vertexOffset + indices[3 * j + 1];
+            buffer[bufferOffset + 2] = vertexOffset + indices[3 * j + 2];
 
             bufferOffset += 3;
         }
+        triangulator.clear();
 
         vertexOffset += numVerticesPerGon;
     }
@@ -513,7 +536,7 @@ int Fac3DDecomposer::fillIndices(char* id, int* buffer, int bufferLength, int lo
     return bufferOffset;
 }
 
-int Fac3DDecomposer::getWireIndicesSize(char* id)
+int Fac3DDecomposer::getWireIndicesSize(int id)
 {
     int numVerticesPerGon = 0;
     int* piNumVerticesPerGon = &numVerticesPerGon;
@@ -523,10 +546,10 @@ int Fac3DDecomposer::getWireIndicesSize(char* id)
     getGraphicObjectProperty(id, __GO_DATA_MODEL_NUM_VERTICES_PER_GON__, jni_int, (void**) &piNumVerticesPerGon);
     getGraphicObjectProperty(id, __GO_DATA_MODEL_NUM_GONS__, jni_int, (void**) &piNumGons);
 
-    return 2*numVerticesPerGon*numGons;
+    return 2 * numVerticesPerGon * numGons;
 }
 
-int Fac3DDecomposer::fillWireIndices(char* id, int* buffer, int bufferLength, int logMask)
+int Fac3DDecomposer::fillWireIndices(int id, int* buffer, int bufferLength, int logMask)
 {
     double* x = NULL;
     double* y = NULL;
@@ -563,9 +586,9 @@ int Fac3DDecomposer::fillWireIndices(char* id, int* buffer, int bufferLength, in
 
         for (int j = 0; j < numVerticesPerGon; j++)
         {
-            xc = x[vertexOffset+j];
-            yc = y[vertexOffset+j];
-            zc = z[vertexOffset+j];
+            xc = x[vertexOffset + j];
+            yc = y[vertexOffset + j];
+            zc = z[vertexOffset + j];
 
             if (!DecompositionUtils::isValid(xc, yc, zc) || !DecompositionUtils::isLogValid(xc, yc, zc, logMask))
             {
@@ -583,7 +606,7 @@ int Fac3DDecomposer::fillWireIndices(char* id, int* buffer, int bufferLength, in
         for (int j = 0; j < numVerticesPerGon; j++)
         {
             buffer[bufferOffset] = vertexOffset + j;
-            buffer[bufferOffset+1] = vertexOffset + (j+1) % numVerticesPerGon;
+            buffer[bufferOffset + 1] = vertexOffset + (j + 1) % numVerticesPerGon;
 
             bufferOffset += 2;
         }
