@@ -301,7 +301,7 @@ int sci_drawaxis(char *fname, void* pvApiCtx)
             }
             break;
         default:
-            Scierror(999, _("%: Wrong value for %s '%c': '%s', '%s' and '%s' expected.\n"), fname, "tics", dir, "r", "v", "i");
+            Scierror(999, _("%s: Wrong value for %s '%c': '%s', '%s' and '%s' expected.\n"), fname, "tics", dir, "r", "v", "i");
             freeAllocatedSingleString(format);
             freeAllocatedMatrixOfString(opts[8].iRows, opts[8].iCols, val);
             return 0;
