@@ -73,6 +73,7 @@ import static org.scilab.modules.graphic_objects.graphicObject.GraphicObjectProp
 import static org.scilab.modules.graphic_objects.graphicObject.GraphicObjectProperties.__GO_VALID__;
 import static org.scilab.modules.graphic_objects.graphicObject.GraphicObjectProperties.__GO_VISIBLE__;
 import static org.scilab.modules.graphic_objects.graphicObject.GraphicObjectProperties.__GO_WAITBAR__;
+import static org.scilab.modules.graphic_objects.graphicObject.GraphicObjectProperties.__GO_UI_FOCUS__;
 import static org.scilab.modules.gui.utils.Debug.DEBUG;
 
 import java.awt.Component;
@@ -793,6 +794,11 @@ public final class SwingView implements GraphicView {
             return;
         }
 
+        if(property == __GO_UI_FOCUS__) {
+            requestFocus(registeredObject);
+            return;
+        }
+
         /* Do not update axes on EDT to avoid dead locks between SwingView & DrawerVisitor */
         /* Test which freezes without this condition: bug_1257.tst in graphics */
         int type = (Integer) GraphicController.getController().getProperty(id, __GO_TYPE__);
@@ -1605,4 +1611,15 @@ public final class SwingView implements GraphicView {
             updatedComponent.validate();
         }
     }
+
+    private void requestFocus(TypedObject updatedObject) {
+        SwingViewObject uicontrol = updatedObject.getValue();
+        if (uicontrol instanceof SwingScilabScrollableFrame) {
+            ((SwingScilabScrollableFrame) uicontrol).requestFocus();
+        } else if (uicontrol instanceof SwingScilabFrame) {
+            ((SwingScilabFrame) uicontrol).requestFocus();
+        } else {
+            ((Widget) uicontrol).requestFocus();
+        }
+    }
 }
