@@ -17,6 +17,9 @@
 package org.scilab.modules.gui.editor;
 
 
+import org.scilab.modules.renderer.utils.CommonHandler;
+import org.scilab.modules.renderer.utils.EntityPicker;
+import org.scilab.modules.renderer.utils.AxesHandler;
 import java.awt.event.ActionListener;
 import java.awt.event.ActionEvent;
 import java.awt.event.MouseEvent;
@@ -30,10 +33,10 @@ import javax.swing.JPopupMenu;
 import org.scilab.modules.gui.datatip.DatatipManager;
 import org.scilab.modules.gui.editor.ScilabClipboard;
 import org.scilab.modules.gui.editor.SystemClipboard;
-import org.scilab.modules.gui.editor.PolylineHandler;
+import org.scilab.modules.renderer.utils.PolylineHandler;
 import org.scilab.modules.gui.editor.GEDPicker;
 import org.scilab.modules.gui.editor.LabelHandler;
-import org.scilab.modules.gui.editor.LegendHandler;
+import org.scilab.modules.renderer.utils.LegendHandler;
 import org.scilab.modules.gui.editor.action.EditorHistory;
 import org.scilab.modules.gui.editor.action.ActionDelete;
 import org.scilab.modules.gui.editor.action.ActionLegend;
@@ -69,6 +72,7 @@ public class Editor {
     JMenu labels, legends;
 
     EntityPicker.LegendInfo selectedLegend = null;
+    EntityPicker.SurfaceInfo selectedSurface = null;
     Integer selected = null;
     Integer figureUid = null;
     Integer[] lastClick = { 0, 0 };
@@ -304,8 +308,8 @@ public class Editor {
         paste.setToolTipText(Messages.gettext("Paste copied object on this figure"));
         delete = new JMenuItem(Messages.gettext("Delete"));
         delete.setToolTipText(Messages.gettext("Delete selected object"));
-        clear = new JMenuItem(Messages.gettext("Clear"));
-        clear.setToolTipText(Messages.gettext("Clears the figure"));
+        clear = new JMenuItem(Messages.gettext("Clear axes"));
+        clear.setToolTipText(Messages.gettext("Delete axes contents and labels"));
         hide = new JMenuItem(Messages.gettext("Hide"));
         hide.setToolTipText(Messages.gettext("Hide selected object"));
         unhide = new JMenuItem(Messages.gettext("Unhide all"));
@@ -313,13 +317,13 @@ public class Editor {
         clipboardCopy = new JMenuItem(Messages.gettext("Copy to Clipboard"));
         clipboardCopy.setToolTipText(Messages.gettext("Copy figure to system clipboard"));
         title = new JMenuItem(Messages.gettext("Title"));
-        title.setToolTipText(Messages.gettext("Insert a title"));
+        title.setToolTipText(Messages.gettext("Set the axes main title"));
         labelX = new JMenuItem(Messages.gettext("Label X"));
-        labelX.setToolTipText(Messages.gettext("Insert a label in X axis"));
+        labelX.setToolTipText(Messages.gettext("Set the X axis label"));
         labelY = new JMenuItem(Messages.gettext("Label Y"));
-        labelY.setToolTipText(Messages.gettext("Insert a label in Y axis"));
+        labelY.setToolTipText(Messages.gettext("Set the Y axis label"));
         labelZ = new JMenuItem(Messages.gettext("Label Z"));
-        labelZ.setToolTipText(Messages.gettext("Insert a label in Z axis"));
+        labelZ.setToolTipText(Messages.gettext("Set the Z axis label"));
         insert = new JMenuItem(Messages.gettext("Insert"));
         insert.setToolTipText(Messages.gettext("Insert a legend into the selected curve"));
         remove = new JMenuItem(Messages.gettext("Remove"));
@@ -816,19 +820,19 @@ public class Editor {
         if (selectedLegend != null) {
             selectedType = SelectionType.LEGEND;
             return selectedLegend.legend;
-        } else {
-            /*try pick a polyline*/
-            Integer picked = entityPicker.pick(figureUid, pos[0], pos[1]);
-            if (picked != null) {
-                selectedType = SelectionType.POLYLINE;
-                return picked;
-            } else {
-                picked = entityPicker.pickSurface(figureUid, pos);
-                if (picked != null) {
-                    selectedType = SelectionType.SURFACE;
-                }
-                return picked;
-            }
         }
+        /*try pick a polyline*/
+        Integer picked = entityPicker.pick(figureUid, pos[0], pos[1]);
+        if (picked != null) {
+            selectedType = SelectionType.POLYLINE;
+            return picked;
+        }
+        /* try pick a surface */
+        selectedSurface = entityPicker.pickSurface(figureUid, pos);
+        if (selectedSurface != null && selectedSurface.surface != null) {
+            selectedType = SelectionType.SURFACE;
+            return selectedSurface.surface;
+        }
+        return null;
     }
 }
