@@ -62,16 +62,16 @@ HDF5_SCILAB_IMPEXP int closeList(int _iFile,  void* _pvList, char* _pstListName,
 
 /*scilab 6*/
 
-HDF5_SCILAB_IMPEXP int writeDoubleMatrix6(int parent, const char* name, int dims, int* pdims, double* data);
-HDF5_SCILAB_IMPEXP int writeDoubleComplexMatrix6(int parent, const char* name, int dims, int* pdims, double* real, double* img);
-HDF5_SCILAB_IMPEXP int writeStringMatrix6(int parent, const char* name, int dims, int* pdims, char** data);
-HDF5_SCILAB_IMPEXP int writeBooleanMatrix6(int parent, const char* name, int dims, int* pdims, int* data);
-HDF5_SCILAB_IMPEXP int writeIntegerMatrix6(int parent, const char* name, int type, const char* prec, int dims, int* pdims, void* data);
+HDF5_SCILAB_IMPEXP int writeDoubleMatrix6(int parent, const char* name, int dims, int* pdims, double* data, hid_t xfer_plist);
+HDF5_SCILAB_IMPEXP int writeDoubleComplexMatrix6(int parent, const char* name, int dims, int* pdims, double* real, double* img, hid_t xfer_plist);
+HDF5_SCILAB_IMPEXP int writeStringMatrix6(int parent, const char* name, int dims, int* pdims, char** data, hid_t xfer_plist);
+HDF5_SCILAB_IMPEXP int writeBooleanMatrix6(int parent, const char* name, int dims, int* pdims, int* data, hid_t xfer_plist);
+HDF5_SCILAB_IMPEXP int writeIntegerMatrix6(int parent, const char* name, int type, const char* prec, int dims, int* pdims, void* data, hid_t xfer_plist);
 
-HDF5_SCILAB_IMPEXP int openList6(int parent, const char *name, const char* type);
+HDF5_SCILAB_IMPEXP int openList6(int parent, const char* name, const char* type);
 HDF5_SCILAB_IMPEXP int closeList6(int lst);
-HDF5_SCILAB_IMPEXP int addItemStruct6(int dataset, hobj_ref_t * refs, int pos, const char *name);
-HDF5_SCILAB_IMPEXP int writeStructField6(int parent, const char* name, int dims, int* pdims, hobj_ref_t * refs);
-HDF5_SCILAB_IMPEXP int writeVoid6(int parent, const char* name);
-HDF5_SCILAB_IMPEXP int writeUndefined6(int parent, const char* name);
+HDF5_SCILAB_IMPEXP int addItemStruct6(int dataset, hobj_ref_t* refs, int pos, const char* name);
+HDF5_SCILAB_IMPEXP int writeStructField6(int parent, const char* name, int dims, int* pdims, hobj_ref_t* refs, hid_t xfer_plist);
+HDF5_SCILAB_IMPEXP int writeVoid6(int parent, const char* name, hid_t xfer_plist);
+HDF5_SCILAB_IMPEXP int writeUndefined6(int parent, const char* name, hid_t xfer_plist);
 #endif /* !__H5_WRITEDATATOFILE_H__ */
