@@ -41,9 +41,9 @@ typedef struct __VAR_INFO6__
     char info[128];
     std::string name;
     std::string ctype;
-    int type;
-    int size;
-    int dims;
+    int type = 0;
+    int size = 0;
+    int dims = 0;
     std::vector<int> pdims;
 } VarInfo6;
 
@@ -314,6 +314,7 @@ static bool read_short_data(int dataset, VarInfo6& info)
         return false;
     }
 
+    closeDataSet(dataset);
     return true;
 }
 
@@ -569,6 +570,7 @@ static bool read_boolean_sparse(int dataset, VarInfo6& info)
     readInteger32Matrix(datannz, &nnz);
 
     info.dims = 2;
+    info.pdims.resize(2);
     info.pdims[0] = pdims[0];
     info.pdims[1] = pdims[1];
     //rows(int) + nnz(int)
@@ -608,6 +610,7 @@ static bool read_poly(int dataset, VarInfo6& info)
         {
             return false;
         }
+        info.dims = dims;
         info.size += datasize * sizeof(double) * (complex + 1);
     }
 
@@ -706,7 +709,7 @@ static bool read_struct(int dataset, VarInfo6& info)
         std::string cname(name);
         FREE(name);
 
-        if (cname != "__dims__" && cname != "__refs__")
+        if (cname != "__dims__" && cname != "__refs__" && cname != "__fields__")
         {
             int dataref = getDataSetIdFromName(dataset, cname.data());
             if (dataref < 0)
@@ -735,7 +738,11 @@ static bool read_struct(int dataset, VarInfo6& info)
             //import field
             for (int j = 0; j < refcount; ++j)
             {
-                int data = H5Rdereference(refs, H5R_OBJECT, &vrefs[j]);
+                int data = H5Rdereference(refs,
+#if H5_VERSION_GE(1,10,0)
+                                          H5P_DATASET_ACCESS_DEFAULT,
+#endif
+                                          H5R_OBJECT, &vrefs[j]);
                 if (data < 0)
                 {
                     return false;
