@@ -53,24 +53,50 @@ extern "C"
 static bool isVarExist(int _iFile, const char* _pstVarName);
 static int extractVarNameList(int* pvCtx, int _iStart, int _iEnd, char** _pstNameList);
 
-int export_data(int parent, const std::string& name, types::InternalType* data);
-static int export_double(int parent, const std::string& name, types::Double* data);
-static int export_string(int parent, const std::string& name, types::String* data);
-static int export_boolean(int parent, const std::string& name, types::Bool* data);
-static int export_list(int parent, const std::string& name, types::List* data);
-static int export_struct(int parent, const std::string& name, types::Struct* data, const char* type = g_SCILAB_CLASS_STRUCT);
-template <class T> static int export_int(int parent, const std::string& name, int type, const char* prec, T* data);
-static int export_poly(int parent, const std::string& name, types::Polynom* data);
-static int export_sparse(int parent, const std::string& name, types::Sparse* data);
-static int export_cell(int parent, const std::string& name, types::Cell* data);
-static int export_macro(int parent, const std::string& name, types::Macro* data);
-static int export_usertype(int parent, const std::string& name, types::UserType* data);
+int export_data(int parent, const std::string& name, types::InternalType* data, hid_t xfer_plist_id);
+static int export_double(int parent, const std::string& name, types::Double* data, hid_t xfer_plist_id);
+static int export_string(int parent, const std::string& name, types::String* data, hid_t xfer_plist_id);
+static int export_boolean(int parent, const std::string& name, types::Bool* data, hid_t xfer_plist_id);
+static int export_list(int parent, const std::string& name, types::List* data, hid_t xfer_plist_id);
+static int export_struct(int parent, const std::string& name, types::Struct* data, const char* type, hid_t xfer_plist_id);
+template <class T> static int export_int(int parent, const std::string& name, int type, const char* prec, T* data, hid_t xfer_plist_id);
+static int export_poly(int parent, const std::string& name, types::Polynom* data, hid_t xfer_plist_id);
+static int export_sparse(int parent, const std::string& name, types::Sparse* data, hid_t xfer_plist_id);
+static int export_cell(int parent, const std::string& name, types::Cell* data, hid_t xfer_plist_id);
+static int export_macro(int parent, const std::string& name, types::Macro* data, hid_t xfer_plist_id);
+static int export_usertype(int parent, const std::string& name, types::UserType* data, hid_t xfer_plist_id);
 
-static int export_boolean_sparse(int parent, const std::string& name, types::SparseBool* data);
-static int export_handles(int parent, const std::string& name, types::GraphicHandle* data);
-static int export_void(int parent, const std::string& name);
-static int export_undefined(int parent, const std::string& name);
+static int export_boolean_sparse(int parent, const std::string& name, types::SparseBool* data, hid_t xfer_plist_id);
+static int export_handles(int parent, const std::string& name, types::GraphicHandle* data, hid_t xfer_plist_id);
+static int export_void(int parent, const std::string& name, hid_t xfer_plist_id);
+static int export_undefined(int parent, const std::string& name, hid_t xfer_plist_id);
 
+/*--------------------------------------------------------------------------*/
+// Custom properties for raw data transfer
+//
+// Passing plist_id as XFER parameter will let H5Dwrite re-use the same
+// internal buffers around.
+struct CustomXFER
+{
+    // from HDF5 doc, "the default value for the maximum buffer is 1 Mb."
+    const hsize_t size = 1024 * 1024;
+
+    hid_t plist_id;
+    uint8_t* tconv;
+    uint8_t* bkg;
+
+    CustomXFER() : plist_id(H5Pcreate(H5P_DATASET_XFER)), tconv(new uint8_t[size]), bkg(new uint8_t[size])
+    {
+        H5Pset_buffer(plist_id, size, tconv, bkg);
+    }
+
+    ~CustomXFER()
+    {
+        H5Pclose(plist_id);
+        delete[] tconv;
+        delete[] bkg;
+    }
+};
 /*--------------------------------------------------------------------------*/
 static const std::string fname("save");
 /*--------------------------------------------------------------------------*/
@@ -78,6 +104,7 @@ types::Function::ReturnValue sci_hdf5_save(types::typed_list &in, int _iRetCount
 {
     int iH5File = 0;
     bool bAppendMode = false;
+    bool isNewFile = true;
     int rhs = static_cast<int>(in.size());
     std::string filename;
     std::map<std::string, types::InternalType*> vars;
@@ -136,32 +163,36 @@ types::Function::ReturnValue sci_hdf5_save(types::typed_list &in, int _iRetCount
     {
         for (int i = 1; i < rhs; ++i)
         {
-            if (in[i]->getId() != types::InternalType::IdScalarString)
+            if (!in[i]->isString())
             {
-                Scierror(999, _("%s: Wrong type for input argument #%d: A String expected.\n"), fname.data(), i+1);
+                Scierror(999, _("%s: Wrong type for input argument #%d: A String expected.\n"), fname.data(), i + 1);
                 return types::Function::Error;
             }
 
-            wchar_t* wvar = in[i]->getAs<types::String>()->get()[0];
-            if (wcscmp(wvar, L"-append") == 0)
-            {
-                bAppendMode = true;
-                continue;
+            types::String *pS = in[i]->getAs<types::String>(); 
+            wchar_t* wvar = pS->get(0);
+            if (wcscmp(wvar, L"-append") == 0) {
+              bAppendMode = true;
+              continue;
             }
 
-            types::InternalType* pIT = ctx->get(symbol::Symbol(wvar));
-            if (pIT == NULL)
+            for (int j = 0; j < pS->getSize(); j++)
             {
-                Scierror(999, _("%s: Wrong value for input argument #%d: Defined variable expected.\n"), fname.data(), i + 1);
-                return types::Function::Error;
+                wvar = pS->get(j);
+                types::InternalType* pIT = ctx->get(symbol::Symbol(wvar));
+                if (pIT == NULL)
+                {
+                    Scierror(999, _("%s: Wrong value for input argument #%d: Defined variable expected.\n"), fname.data(), i + 1);
+                    return types::Function::Error;
+                }
+
+                char* cvar = wide_string_to_UTF8(wvar);
+                std::string var(cvar);
+                FREE(cvar);
+
+                //check var exists
+                vars[var] = pIT;                
             }
-
-            char* cvar = wide_string_to_UTF8(wvar);
-            std::string var(cvar);
-            FREE(cvar);
-
-            //check var exists
-            vars[var] = pIT;
         }
     }
     //check append option
@@ -175,6 +206,7 @@ types::Function::ReturnValue sci_hdf5_save(types::typed_list &in, int _iRetCount
         }
         else
         {
+            isNewFile = false;
             int iVersion = getSODFormatAttribute(iH5File);
             if (iVersion != SOD_FILE_VERSION)
             {
@@ -199,12 +231,15 @@ types::Function::ReturnValue sci_hdf5_save(types::typed_list &in, int _iRetCount
         }
         else
         {
-            Scierror(999, _("%s: Cannot open file %s.\n"), fname.data() , filename.data());
+            Scierror(999, _("%s: Cannot open file %s.\n"), fname.data(), filename.data());
         }
 
         return types::Function::Error;
     }
 
+    // share common work buffers for all serialized data
+    CustomXFER xfer;
+
     // export data
     for (const auto var : vars)
     {
@@ -227,11 +262,14 @@ types::Function::ReturnValue sci_hdf5_save(types::typed_list &in, int _iRetCount
             }
         }
 
-        int iDataset = export_data(iH5File, var.first, var.second);
+        int iDataset = export_data(iH5File, var.first, var.second, xfer.plist_id);
         if (iDataset == -1)
         {
             closeHDF5File(iH5File);
-            deleteafile(filename.data());
+            if (isNewFile)
+            {
+                deleteafile(filename.data());
+            }
             Scierror(999, _("%s: Unable to export variable \'%s\' in file \'%s\'.\n"), fname.data(), var.first.data(), filename.data());
             return types::Function::Error;
         }
@@ -283,84 +321,84 @@ static bool isVarExist(int _iFile, const char* _pstVarName)
     return false;
 }
 /*--------------------------------------------------------------------------*/
-int export_data(int parent, const std::string& name, types::InternalType* data)
+int export_data(int parent, const std::string& name, types::InternalType* data, hid_t xfer_plist_id)
 {
     int dataset = -1;
     switch (data->getType())
     {
         case types::InternalType::ScilabDouble:
-            dataset = export_double(parent, name, data->getAs<types::Double>());
+            dataset = export_double(parent, name, data->getAs<types::Double>(), xfer_plist_id);
             break;
         case types::InternalType::ScilabString:
-            dataset = export_string(parent, name, data->getAs<types::String>());
+            dataset = export_string(parent, name, data->getAs<types::String>(), xfer_plist_id);
             break;
         case types::InternalType::ScilabBool:
-            dataset = export_boolean(parent, name, data->getAs<types::Bool>());
+            dataset = export_boolean(parent, name, data->getAs<types::Bool>(), xfer_plist_id);
             break;
         case types::InternalType::ScilabTList:
         case types::InternalType::ScilabList:
         case types::InternalType::ScilabMList:
-            dataset = export_list(parent, name, data->getAs<types::List>());
+            dataset = export_list(parent, name, data->getAs<types::List>(), xfer_plist_id);
             break;
         case types::InternalType::ScilabInt8:
-            dataset = export_int(parent, name, H5T_NATIVE_INT8, "8", data->getAs<types::Int8>());
+            dataset = export_int(parent, name, H5T_NATIVE_INT8, "8", data->getAs<types::Int8>(), xfer_plist_id);
             break;
         case types::InternalType::ScilabInt16:
-            dataset = export_int(parent, name, H5T_NATIVE_INT16, "16", data->getAs<types::Int16>());
+            dataset = export_int(parent, name, H5T_NATIVE_INT16, "16", data->getAs<types::Int16>(), xfer_plist_id);
             break;
         case types::InternalType::ScilabInt32:
-            dataset = export_int(parent, name, H5T_NATIVE_INT32, "32", data->getAs<types::Int32>());
+            dataset = export_int(parent, name, H5T_NATIVE_INT32, "32", data->getAs<types::Int32>(), xfer_plist_id);
             break;
         case types::InternalType::ScilabInt64:
-            dataset = export_int(parent, name, H5T_NATIVE_INT64, "64", data->getAs<types::Int64>());
+            dataset = export_int(parent, name, H5T_NATIVE_INT64, "64", data->getAs<types::Int64>(), xfer_plist_id);
             break;
         case types::InternalType::ScilabUInt8:
-            dataset = export_int(parent, name, H5T_NATIVE_UINT8, "u8", data->getAs<types::UInt8>());
+            dataset = export_int(parent, name, H5T_NATIVE_UINT8, "u8", data->getAs<types::UInt8>(), xfer_plist_id);
             break;
         case types::InternalType::ScilabUInt16:
-            dataset = export_int(parent, name, H5T_NATIVE_UINT16, "u16", data->getAs<types::UInt16>());
+            dataset = export_int(parent, name, H5T_NATIVE_UINT16, "u16", data->getAs<types::UInt16>(), xfer_plist_id);
             break;
         case types::InternalType::ScilabUInt32:
-            dataset = export_int(parent, name, H5T_NATIVE_UINT32, "u32", data->getAs<types::UInt32>());
+            dataset = export_int(parent, name, H5T_NATIVE_UINT32, "u32", data->getAs<types::UInt32>(), xfer_plist_id);
             break;
         case types::InternalType::ScilabUInt64:
-            dataset = export_int(parent, name, H5T_NATIVE_UINT64, "u64", data->getAs<types::UInt64>());
+            dataset = export_int(parent, name, H5T_NATIVE_UINT64, "u64", data->getAs<types::UInt64>(), xfer_plist_id);
             break;
         case types::InternalType::ScilabStruct:
-            dataset = export_struct(parent, name, data->getAs<types::Struct>());
+            dataset = export_struct(parent, name, data->getAs<types::Struct>(), g_SCILAB_CLASS_STRUCT, xfer_plist_id);
             break;
         case types::InternalType::ScilabPolynom:
-            dataset = export_poly(parent, name, data->getAs<types::Polynom>());
+            dataset = export_poly(parent, name, data->getAs<types::Polynom>(), xfer_plist_id);
             break;
         case types::InternalType::ScilabSparse:
-            dataset = export_sparse(parent, name, data->getAs<types::Sparse>());
+            dataset = export_sparse(parent, name, data->getAs<types::Sparse>(), xfer_plist_id);
             break;
         case types::InternalType::ScilabSparseBool :
-            dataset = export_boolean_sparse(parent, name, data->getAs<types::SparseBool>());
+            dataset = export_boolean_sparse(parent, name, data->getAs<types::SparseBool>(), xfer_plist_id);
             break;
         case types::InternalType::ScilabCell:
-            dataset = export_cell(parent, name, data->getAs<types::Cell>());
+            dataset = export_cell(parent, name, data->getAs<types::Cell>(), xfer_plist_id);
             break;
         case types::InternalType::ScilabVoid:
-            dataset = export_void(parent, name);
+            dataset = export_void(parent, name, xfer_plist_id);
             break;
         case types::InternalType::ScilabListUndefinedOperation:
-            dataset = export_undefined(parent, name);
+            dataset = export_undefined(parent, name, xfer_plist_id);
             break;
         case types::InternalType::ScilabMacro:
-            dataset = export_macro(parent, name, data->getAs<types::Macro>());
+            dataset = export_macro(parent, name, data->getAs<types::Macro>(), xfer_plist_id);
             break;
         case types::InternalType::ScilabMacroFile:
         {
             types::MacroFile* pMF = data->getAs<types::MacroFile>();
-            dataset = export_macro(parent, name, pMF->getMacro());
+            dataset = export_macro(parent, name, pMF->getMacro(), xfer_plist_id);
             break;
         }
         case types::InternalType::ScilabHandle:
-            dataset = export_handles(parent, name, data->getAs<types::GraphicHandle>());
+            dataset = export_handles(parent, name, data->getAs<types::GraphicHandle>(), xfer_plist_id);
             break;
         case types::InternalType::ScilabUserType:
-            dataset = export_usertype(parent, name, data->getAs<types::UserType>());
+            dataset = export_usertype(parent, name, data->getAs<types::UserType>(), xfer_plist_id);
             break;
         default:
         {
@@ -372,7 +410,7 @@ int export_data(int parent, const std::string& name, types::InternalType* data)
 }
 
 /*--------------------------------------------------------------------------*/
-static int export_list(int parent, const std::string& name, types::List* data)
+static int export_list(int parent, const std::string& name, types::List* data, hid_t xfer_plist_id)
 {
     int size = data->getSize();
 
@@ -397,7 +435,7 @@ static int export_list(int parent, const std::string& name, types::List* data)
 
     for (int i = 0; i < size; ++i)
     {
-        if (export_data(dset, std::to_string(i).data(), data->get(i)) == -1)
+        if (export_data(dset, std::to_string(i).data(), data->get(i), xfer_plist_id) == -1)
         {
             closeList6(dset);
             return -1;
@@ -411,29 +449,29 @@ static int export_list(int parent, const std::string& name, types::List* data)
     return dset;
 }
 /*--------------------------------------------------------------------------*/
-static int export_double(int parent, const std::string& name, types::Double* data)
+static int export_double(int parent, const std::string& name, types::Double* data, hid_t xfer_plist_id)
 {
     int dataset = -1;
 
     if (data->isComplex())
     {
-        dataset = writeDoubleComplexMatrix6(parent, name.data(), data->getDims(), data->getDimsArray(), data->get(), data->getImg());
+        dataset = writeDoubleComplexMatrix6(parent, name.data(), data->getDims(), data->getDimsArray(), data->get(), data->getImg(), xfer_plist_id);
     }
     else
     {
-        dataset = writeDoubleMatrix6(parent, name.data(), data->getDims(), data->getDimsArray(), data->get());
+        dataset = writeDoubleMatrix6(parent, name.data(), data->getDims(), data->getDimsArray(), data->get(), xfer_plist_id);
     }
 
     return dataset;
 }
 /*--------------------------------------------------------------------------*/
 template <class T>
-static int export_int(int parent, const std::string& name, int type, const char* prec, T* data)
+static int export_int(int parent, const std::string& name, int type, const char* prec, T* data, hid_t xfer_plist_id)
 {
-    return writeIntegerMatrix6(parent, name.data(), type, prec, data->getDims(), data->getDimsArray(), data->get());
+    return writeIntegerMatrix6(parent, name.data(), type, prec, data->getDims(), data->getDimsArray(), data->get(), xfer_plist_id);
 }
 /*--------------------------------------------------------------------------*/
-static int export_string(int parent, const std::string& name, types::String* data)
+static int export_string(int parent, const std::string& name, types::String* data, hid_t xfer_plist_id)
 {
     int size = data->getSize();
     wchar_t** s = data->get();
@@ -445,7 +483,7 @@ static int export_string(int parent, const std::string& name, types::String* dat
         v[i] = wide_string_to_UTF8(s[i]);
     }
 
-    int dset = writeStringMatrix6(parent, name.data(), data->getDims(), data->getDimsArray(), v.data());
+    int dset = writeStringMatrix6(parent, name.data(), data->getDims(), data->getDimsArray(), v.data(), xfer_plist_id);
 
     //release memory
     for (int i = 0; i < size; ++i)
@@ -456,18 +494,18 @@ static int export_string(int parent, const std::string& name, types::String* dat
     return dset;
 }
 /*--------------------------------------------------------------------------*/
-static int export_boolean(int parent, const std::string& name, types::Bool* data)
+static int export_boolean(int parent, const std::string& name, types::Bool* data, hid_t xfer_plist_id)
 {
-    return writeBooleanMatrix6(parent, name.data(), data->getDims(), data->getDimsArray(), data->get());
+    return writeBooleanMatrix6(parent, name.data(), data->getDims(), data->getDimsArray(), data->get(), xfer_plist_id);
 }
 /*--------------------------------------------------------------------------*/
-static int export_struct(int parent, const std::string& name, types::Struct* data, const char* type)
+static int export_struct(int parent, const std::string& name, types::Struct* data, const char* type, hid_t xfer_plist_id)
 {
     //create a group with struct name
     int dset = openList6(parent, name.data(), type);
     //store struct dimensions
     std::vector<int> dims = {1, data->getDims()};
-    int ret = writeIntegerMatrix6(dset, "__dims__", H5T_NATIVE_INT32, "32", 2, dims.data(), data->getDimsArray());
+    int ret = writeIntegerMatrix6(dset, "__dims__", H5T_NATIVE_INT32, "32", 2, dims.data(), data->getDimsArray(), xfer_plist_id);
     if (ret < 0)
     {
         return -1;
@@ -497,7 +535,7 @@ static int export_struct(int parent, const std::string& name, types::Struct* dat
     wchar_t** pfields = fields->get();
 
     //save fields list in vector to keep order
-    export_string(dset, "__fields__", fields);
+    export_string(dset, "__fields__", fields, xfer_plist_id);
 
     std::vector<hobj_ref_t> vrefs(size);
     //fill main group with struct field name
@@ -512,7 +550,7 @@ static int export_struct(int parent, const std::string& name, types::Struct* dat
             std::string refname(cfield);
             refname += "_" + std::to_string(j);
             //export data in refs group
-            int ref = export_data(refs, refname, val);
+            int ref = export_data(refs, refname, val, xfer_plist_id);
             //create reference of data
             ret = addItemStruct6(refs, vrefs.data(), j, refname.data());
             if (ret)
@@ -523,7 +561,7 @@ static int export_struct(int parent, const std::string& name, types::Struct* dat
             }
         }
 
-        ret = writeStructField6(dset, cfield, data->getDims(), data->getDimsArray(), vrefs.data());
+        ret = writeStructField6(dset, cfield, data->getDims(), data->getDimsArray(), vrefs.data(), xfer_plist_id);
         FREE(cfield);
         if (ret < 0)
         {
@@ -547,23 +585,23 @@ static int export_struct(int parent, const std::string& name, types::Struct* dat
     return dset;
 }
 /*--------------------------------------------------------------------------*/
-static int export_void(int parent, const std::string& name)
+static int export_void(int parent, const std::string& name, hid_t xfer_plist_id)
 {
-    return writeVoid6(parent, name.data());
+    return writeVoid6(parent, name.data(), xfer_plist_id);
 }
 /*--------------------------------------------------------------------------*/
-static int export_undefined(int parent, const std::string& name)
+static int export_undefined(int parent, const std::string& name, hid_t xfer_plist_id)
 {
-    return writeUndefined6(parent, name.data());
+    return writeUndefined6(parent, name.data(), xfer_plist_id);
 }
 /*--------------------------------------------------------------------------*/
-static int export_poly(int parent, const std::string& name, types::Polynom* data)
+static int export_poly(int parent, const std::string& name, types::Polynom* data, hid_t xfer_plist_id)
 {
     //create a group with struct name
     int dset = openList6(parent, name.data(), g_SCILAB_CLASS_POLY);
     //store struct dimensions
     std::vector<int> dims = {1, data->getDims()};
-    int ret = writeIntegerMatrix6(dset, "__dims__", H5T_NATIVE_INT32, "32", 2, dims.data(), data->getDimsArray());
+    int ret = writeIntegerMatrix6(dset, "__dims__", H5T_NATIVE_INT32, "32", 2, dims.data(), data->getDimsArray(), xfer_plist_id);
     if (ret < 0)
     {
         return -1;
@@ -572,7 +610,7 @@ static int export_poly(int parent, const std::string& name, types::Polynom* data
     //store variable name
     std::vector<int> vardims = {1, 1};
     char* varname = wide_string_to_UTF8(data->getVariableName().data());
-    ret = writeStringMatrix6(dset, "__varname__", 2, vardims.data(), &varname);
+    ret = writeStringMatrix6(dset, "__varname__", 2, vardims.data(), &varname, xfer_plist_id);
     FREE(varname);
     if (ret < 0)
     {
@@ -600,11 +638,11 @@ static int export_poly(int parent, const std::string& name, types::Polynom* data
         std::string polyname(std::to_string(j));
         if (complex)
         {
-            writeDoubleComplexMatrix6(refs, polyname.data(), 2, ssdims.data(), val->get(), val->getImg());
+            writeDoubleComplexMatrix6(refs, polyname.data(), 2, ssdims.data(), val->get(), val->getImg(), xfer_plist_id);
         }
         else
         {
-            writeDoubleMatrix6(refs, polyname.data(), 2, ssdims.data(), val->get());
+            writeDoubleMatrix6(refs, polyname.data(), 2, ssdims.data(), val->get(), xfer_plist_id);
         }
 
         //create reference of data
@@ -629,7 +667,7 @@ static int export_poly(int parent, const std::string& name, types::Polynom* data
     return dset;
 }
 /*--------------------------------------------------------------------------*/
-static int export_sparse(int parent, const std::string& name, types::Sparse* data)
+static int export_sparse(int parent, const std::string& name, types::Sparse* data, hid_t xfer_plist_id)
 {
     int nnz = static_cast<int>(data->nonZeros());
     int row = data->getRows();
@@ -637,7 +675,7 @@ static int export_sparse(int parent, const std::string& name, types::Sparse* dat
     int dset = openList6(parent, name.data(), g_SCILAB_CLASS_SPARSE);
     //store sparse dimensions
     std::vector<int> dims = {1, data->getDims()};
-    int ret = writeIntegerMatrix6(dset, "__dims__", H5T_NATIVE_INT32, "32", 2, dims.data(), data->getDimsArray());
+    int ret = writeIntegerMatrix6(dset, "__dims__", H5T_NATIVE_INT32, "32", 2, dims.data(), data->getDimsArray(), xfer_plist_id);
     if (ret < 0)
     {
         return -1;
@@ -645,7 +683,7 @@ static int export_sparse(int parent, const std::string& name, types::Sparse* dat
 
     //store numbers of non zero by rows.
     std::vector<int> dimsnnz = {1, 1};
-    ret = writeIntegerMatrix6(dset, "__nnz__", H5T_NATIVE_INT32, "32", 2, dimsnnz.data(), &nnz);
+    ret = writeIntegerMatrix6(dset, "__nnz__", H5T_NATIVE_INT32, "32", 2, dimsnnz.data(), &nnz, xfer_plist_id);
     if (ret < 0)
     {
         return -1;
@@ -655,7 +693,7 @@ static int export_sparse(int parent, const std::string& name, types::Sparse* dat
     int innercount = 0;
     int* inner = data->getInnerPtr(&innercount);
     std::vector<int> dimsinner = {1, nnz};
-    ret = writeIntegerMatrix6(dset, "__inner__", H5T_NATIVE_INT32, "32", 2, dimsinner.data(), inner);
+    ret = writeIntegerMatrix6(dset, "__inner__", H5T_NATIVE_INT32, "32", 2, dimsinner.data(), inner, xfer_plist_id);
     if (ret < 0)
     {
         return -1;
@@ -664,7 +702,7 @@ static int export_sparse(int parent, const std::string& name, types::Sparse* dat
     int outercount = 0;
     int* outer = data->getOuterPtr(&outercount);
     std::vector<int> dimsouter = {1, outercount + 1};
-    ret = writeIntegerMatrix6(dset, "__outer__", H5T_NATIVE_INT32, "32", 2, dimsouter.data(), outer);
+    ret = writeIntegerMatrix6(dset, "__outer__", H5T_NATIVE_INT32, "32", 2, dimsouter.data(), outer, xfer_plist_id);
     if (ret < 0)
     {
         return -1;
@@ -683,7 +721,7 @@ static int export_sparse(int parent, const std::string& name, types::Sparse* dat
 
 
         std::vector<int> dimsdata = {1, nnz};
-        ret = writeDoubleComplexMatrix6(dset, "__data__", 2, dimsdata.data(), real, img);
+        ret = writeDoubleComplexMatrix6(dset, "__data__", 2, dimsdata.data(), real, img, xfer_plist_id);
         delete[] real;
         delete[] img;
         if (ret < 0)
@@ -694,7 +732,7 @@ static int export_sparse(int parent, const std::string& name, types::Sparse* dat
     else
     {
         std::vector<int> dimsdata = {1, nnz};
-        ret = writeDoubleMatrix6(dset, "__data__", 2, dimsdata.data(), data->get());
+        ret = writeDoubleMatrix6(dset, "__data__", 2, dimsdata.data(), data->get(), xfer_plist_id);
         if (ret < 0)
         {
             return -1;
@@ -710,7 +748,7 @@ static int export_sparse(int parent, const std::string& name, types::Sparse* dat
 
 }
 /*--------------------------------------------------------------------------*/
-static int export_boolean_sparse(int parent, const std::string& name, types::SparseBool* data)
+static int export_boolean_sparse(int parent, const std::string& name, types::SparseBool* data, hid_t xfer_plist_id)
 {
     int nnz = static_cast<int>(data->nbTrue());
     int row = data->getRows();
@@ -718,7 +756,7 @@ static int export_boolean_sparse(int parent, const std::string& name, types::Spa
     int dset = openList6(parent, name.data(), g_SCILAB_CLASS_BSPARSE);
     //store sparse dimensions
     std::vector<int> dims = {1, data->getDims()};
-    int ret = writeIntegerMatrix6(dset, "__dims__", H5T_NATIVE_INT32, "32", 2, dims.data(), data->getDimsArray());
+    int ret = writeIntegerMatrix6(dset, "__dims__", H5T_NATIVE_INT32, "32", 2, dims.data(), data->getDimsArray(), xfer_plist_id);
     if (ret < 0)
     {
         return -1;
@@ -726,7 +764,7 @@ static int export_boolean_sparse(int parent, const std::string& name, types::Spa
 
     //store numbers of non zero by rows.
     std::vector<int> dimsnnz = {1, 1};
-    ret = writeIntegerMatrix6(dset, "__nnz__", H5T_NATIVE_INT32, "32", 2, dimsnnz.data(), &nnz);
+    ret = writeIntegerMatrix6(dset, "__nnz__", H5T_NATIVE_INT32, "32", 2, dimsnnz.data(), &nnz, xfer_plist_id);
     if (ret < 0)
     {
         return -1;
@@ -736,7 +774,7 @@ static int export_boolean_sparse(int parent, const std::string& name, types::Spa
     int innercount = 0;
     int* inner = data->getInnerPtr(&innercount);
     std::vector<int> dimsinner = {1, nnz};
-    ret = writeIntegerMatrix6(dset, "__inner__", H5T_NATIVE_INT32, "32", 2, dimsinner.data(), inner);
+    ret = writeIntegerMatrix6(dset, "__inner__", H5T_NATIVE_INT32, "32", 2, dimsinner.data(), inner, xfer_plist_id);
     if (ret < 0)
     {
         return -1;
@@ -745,7 +783,7 @@ static int export_boolean_sparse(int parent, const std::string& name, types::Spa
     int outercount = 0;
     int* outer = data->getOuterPtr(&outercount);
     std::vector<int> dimsouter = {1, outercount + 1};
-    ret = writeIntegerMatrix6(dset, "__outer__", H5T_NATIVE_INT32, "32", 2, dimsouter.data(), outer);
+    ret = writeIntegerMatrix6(dset, "__outer__", H5T_NATIVE_INT32, "32", 2, dimsouter.data(), outer, xfer_plist_id);
     if (ret < 0)
     {
         return -1;
@@ -759,13 +797,13 @@ static int export_boolean_sparse(int parent, const std::string& name, types::Spa
     return dset;
 }
 /*--------------------------------------------------------------------------*/
-static int export_cell(int parent, const std::string& name, types::Cell* data)
+static int export_cell(int parent, const std::string& name, types::Cell* data, hid_t xfer_plist_id)
 {
     //create a group with cell name
     int dset = openList6(parent, name.data(), g_SCILAB_CLASS_CELL);
     //store cell dimensions
     std::vector<int> dims = {1, data->getDims()};
-    int ret = writeIntegerMatrix6(dset, "__dims__", H5T_NATIVE_INT32, "32", 2, dims.data(), data->getDimsArray());
+    int ret = writeIntegerMatrix6(dset, "__dims__", H5T_NATIVE_INT32, "32", 2, dims.data(), data->getDimsArray(), xfer_plist_id);
     if (ret < 0)
     {
         return -1;
@@ -784,7 +822,7 @@ static int export_cell(int parent, const std::string& name, types::Cell* data)
     for (int i = 0; i < size; ++i)
     {
         std::string refname(std::to_string(i));
-        int ref = export_data(refs, refname, it[i]);
+        int ref = export_data(refs, refname, it[i], xfer_plist_id);
     }
 
 
@@ -801,13 +839,13 @@ static int export_cell(int parent, const std::string& name, types::Cell* data)
     return dset;
 }
 
-static int export_handles(int parent, const std::string& name, types::GraphicHandle* data)
+static int export_handles(int parent, const std::string& name, types::GraphicHandle* data, hid_t xfer_plist_id)
 {
     //create a group with cell name
     int dset = openList6(parent, name.data(), g_SCILAB_CLASS_HANDLE);
     //store cell dimensions
     std::vector<int> dims = {1, data->getDims()};
-    int ret = writeIntegerMatrix6(dset, "__dims__", H5T_NATIVE_INT32, "32", 2, dims.data(), data->getDimsArray());
+    int ret = writeIntegerMatrix6(dset, "__dims__", H5T_NATIVE_INT32, "32", 2, dims.data(), data->getDimsArray(), xfer_plist_id);
     if (ret < 0)
     {
         return -1;
@@ -829,7 +867,7 @@ static int export_handles(int parent, const std::string& name, types::GraphicHan
         //get handle uid
         int hl = getObjectFromHandle(static_cast<long>(ll[i]));
         std::string refname(std::to_string(i));
-        if (export_handle(refs, refname, hl) == false)
+        if (export_handle(refs, refname, hl, xfer_plist_id) == false)
         {
             closeList6(refs);
             closeList6(dset);
@@ -842,7 +880,7 @@ static int export_handles(int parent, const std::string& name, types::GraphicHan
     return dset;
 }
 
-static int export_macro(int parent, const std::string& name, types::Macro* data)
+static int export_macro(int parent, const std::string& name, types::Macro* data, hid_t xfer_plist_id)
 {
     int dims[2];
 
@@ -859,7 +897,7 @@ static int export_macro(int parent, const std::string& name, types::Macro* data)
 
     dims[0] = 1;
     dims[1] = static_cast<int>(inputNames.size());
-    writeStringMatrix6(dset, "inputs", 2, dims, inputNames.data());
+    writeStringMatrix6(dset, "inputs", 2, dims, inputNames.data(), xfer_plist_id);
 
     for (auto & in : inputNames)
     {
@@ -876,7 +914,7 @@ static int export_macro(int parent, const std::string& name, types::Macro* data)
 
     dims[0] = 1;
     dims[1] = static_cast<int>(outputNames.size());
-    writeStringMatrix6(dset, "outputs", 2, dims, outputNames.data());
+    writeStringMatrix6(dset, "outputs", 2, dims, outputNames.data(), xfer_plist_id);
 
     for (auto & in : outputNames)
     {
@@ -893,14 +931,13 @@ static int export_macro(int parent, const std::string& name, types::Macro* data)
 
     dims[0] = 1;
     dims[1] = size;
-    writeIntegerMatrix6(dset, "body", H5T_NATIVE_UINT8, "u8", 2, dims, serialAst);
-    free(serialAst);
+    writeIntegerMatrix6(dset, "body", H5T_NATIVE_UINT8, "u8", 2, dims, serialAst, xfer_plist_id);
 
     closeList6(dset);
     return dset;
 }
 
-static int export_usertype(int parent, const std::string& name, types::UserType* data)
+static int export_usertype(int parent, const std::string& name, types::UserType* data, hid_t xfer_plist_id)
 {
     types::InternalType* it = data->save();
     if (it == nullptr)
@@ -959,7 +996,7 @@ static int export_usertype(int parent, const std::string& name, types::UserType*
     ss->set(L"type", new types::String(data->getShortTypeStr().data()));
     ss->set(L"data", it);
 
-    int ret = export_struct(parent, name, str, g_SCILAB_CLASS_USERTYPE);
+    int ret = export_struct(parent, name, str, g_SCILAB_CLASS_USERTYPE, xfer_plist_id);
 
     //protect data against delete
     it->IncreaseRef();
