@@ -3,25 +3,28 @@
  * Copyright (C) 2006 - INRIA - Allan CORNET
  * Copyright (C) 2009 - DIGITEO - Allan CORNET
  *
- * This file must be used under the terms of the CeCILL.
- * This source file is licensed as described in the file COPYING, which
- * you should have received as part of this distribution.  The terms
- * are also available at
- * http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.txt
+ * Copyright (C) 2012 - 2016 - Scilab Enterprises
+ *
+ * This file is hereby licensed under the terms of the GNU GPL v2.0,
+ * pursuant to article 5.3.4 of the CeCILL v.2.1.
+ * This file was originally licensed under the terms of the CeCILL v2.1,
+ * and continues to be available under such terms.
+ * For more information, see the COPYING file which you should have received
+ * along with this program.
  *
  */
 #include <stdio.h>
 #include <stdlib.h> /* _MAX_ENV */
 #include "gw_io.h"
-#include "MALLOC.h"
+#include "sci_malloc.h"
 #include "freeArrayOfString.h"
 #include "localization.h"
 #include "Scierror.h"
-#include "api_scilab.h"
 #include "getenvc.h"
 #include "PATH_MAX.h"
+#include "api_scilab.h"
 /*--------------------------------------------------------------------------*/
-int sci_getenv(char *fname, unsigned long fname_len)
+int sci_getenv(char *fname, void* pvApiCtx)
 {
     SciErr sciErr;
     int ierr = 0;
@@ -36,12 +39,12 @@ int sci_getenv(char *fname, unsigned long fname_len)
 
     int iflag = 0;
 
-    Rhs = Max(Rhs, 0);
+    int iRhs = nbInputArgument(pvApiCtx);
 
     CheckRhs(1, 2);
     CheckLhs(1, 1);
 
-    if (Rhs == 2)
+    if (iRhs == 2)
     {
         sciErr = getVarAddressFromPosition(pvApiCtx, 2, &piAddressVarTwo);
         if (sciErr.iErr)
@@ -53,7 +56,7 @@ int sci_getenv(char *fname, unsigned long fname_len)
 
         if (isStringType(pvApiCtx, piAddressVarTwo) == 0 || isScalar(pvApiCtx, piAddressVarTwo) == 0)
         {
-            Scierror(999, _("%s: Wrong size for input argument #%d: A string expected.\n"), fname, 2);
+            Scierror(999, _("%s: Wrong size for input argument #%d: string expected.\n"), fname, 2);
             return 0;
         }
 
@@ -72,6 +75,10 @@ int sci_getenv(char *fname, unsigned long fname_len)
     sciErr = getVarAddressFromPosition(pvApiCtx, 1, &piAddressVarOne);
     if (sciErr.iErr)
     {
+        if (pStVarTwo)
+        {
+            freeAllocatedSingleString(pStVarTwo);
+        }
         printError(&sciErr, 0);
         Scierror(999, _("%s: Can not read input argument #%d.\n"), fname, 1);
         return 0;
@@ -79,7 +86,11 @@ int sci_getenv(char *fname, unsigned long fname_len)
 
     if (isStringType(pvApiCtx, piAddressVarOne) == 0 || isScalar(pvApiCtx, piAddressVarOne) == 0)
     {
-        Scierror(999, _("%s: Wrong type for input argument #%d: A string expected.\n"), fname, 2);
+        if (pStVarTwo)
+        {
+            freeAllocatedSingleString(pStVarTwo);
+        }
+        Scierror(999, _("%s: Wrong type for input argument #%d: string expected.\n"), fname, 2);
         return 0;
     }
 
@@ -99,14 +110,12 @@ int sci_getenv(char *fname, unsigned long fname_len)
         return 0;
     }
 
-
-    C2F(getenvc)(&ierr, pStVarOne, NULL, &length_env, &iflag);
-
+    getenvc(&ierr, pStVarOne, NULL, &length_env, &iflag);
     if (ierr)
     {
         if (pStVarTwo)
         {
-            if (createSingleString(pvApiCtx, Rhs + 1, pStVarTwo))
+            if (createSingleString(pvApiCtx, iRhs + 1, pStVarTwo))
             {
                 freeAllocatedSingleString(pStVarOne);
                 freeAllocatedSingleString(pStVarTwo);
@@ -115,8 +124,10 @@ int sci_getenv(char *fname, unsigned long fname_len)
             }
             else
             {
-                LhsVar(1) = Rhs + 1;
-                PutLhsVar();
+                freeAllocatedSingleString(pStVarOne);
+                freeAllocatedSingleString(pStVarTwo);
+                LhsVar(1) = iRhs + 1;
+                ReturnArguments(pvApiCtx);
                 return 0;
             }
         }
@@ -139,10 +150,11 @@ int sci_getenv(char *fname, unsigned long fname_len)
         return 0;
     }
 
-    C2F(getenvc)(&ierr, pStVarOne, env_value, &length_env, &iflag);
+    getenvc(&ierr, pStVarOne, env_value, &length_env, &iflag);
+    freeAllocatedSingleString(pStVarOne);
 
     //create variable on stack and return it.
-    if (createSingleString(pvApiCtx, Rhs + 1, env_value))
+    if (createSingleString(pvApiCtx, iRhs + 1, env_value))
     {
         FREE(env_value);
         printError(&sciErr, 0);
@@ -151,8 +163,8 @@ int sci_getenv(char *fname, unsigned long fname_len)
     }
 
     FREE(env_value);
-    LhsVar(1) = Rhs + 1;
-    PutLhsVar();
+    AssignOutputVariable(pvApiCtx, 1) = iRhs + 1;
+    ReturnArguments(pvApiCtx);
 
 
     return 0;
