@@ -2,32 +2,35 @@
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2011 - DIGITEO - Calixte DENIZET
  *
- * This file must be used under the terms of the CeCILL.
- * This source file is licensed as described in the file COPYING, which
- * you should have received as part of this distribution.  The terms
- * are also available at
- * http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.txt
+ * Copyright (C) 2012 - 2016 - Scilab Enterprises
+ *
+ * This file is hereby licensed under the terms of the GNU GPL v2.0,
+ * pursuant to article 5.3.4 of the CeCILL v.2.1.
+ * This file was originally licensed under the terms of the CeCILL v2.1,
+ * and continues to be available under such terms.
+ * For more information, see the COPYING file which you should have received
+ * along with this program.
  *
  */
 
 #include "ScilabPreferences.hxx"
 #include "GiwsException.hxx"
+#include "preferences_gw.hxx"
 
 extern "C"
 {
-#include "gw_preferences.h"
 #include "Scierror.h"
 #include "api_scilab.h"
 #include "localization.h"
 #include "getScilabJavaVM.h"
 #include "expandPathVariable.h"
-#include "MALLOC.h"
+#include "sci_malloc.h"
 }
 
 using namespace org_scilab_modules_preferences;
 
 /*--------------------------------------------------------------------------*/
-int sci_addModulePreferences(char * fname, unsigned long fname_len)
+int sci_addModulePreferences(char * fname, void *pvApiCtx)
 {
     SciErr err;
     int * addr = 0;
@@ -53,7 +56,7 @@ int sci_addModulePreferences(char * fname, unsigned long fname_len)
 
         if (!isStringType(pvApiCtx, addr))
         {
-            Scierror(999, gettext("%s: Wrong type for input argument #%i: A string expected.\n"), fname, i + 1);
+            Scierror(999, gettext("%s: Wrong type for input argument #%i: string expected.\n"), fname, i + 1);
             for (int j = 0; j < i; j++)
             {
                 if (array[j])
@@ -64,7 +67,10 @@ int sci_addModulePreferences(char * fname, unsigned long fname_len)
             return 0;
         }
 
-        getAllocatedSingleString(pvApiCtx, addr, array[i]);
+        if (getAllocatedSingleString(pvApiCtx, addr, array[i]))
+        {
+            return 0;
+        }
     }
 
     expTbxPath = expandPathVariable(const_cast<char *>(tbxPath));
