@@ -1,6 +1,7 @@
 /*
  *  Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  *  Copyright (C) 2014-2016 - Scilab Enterprises - Clement DAVID
+ *  Copyright (C) 2017-2018 - ESI Group - Clement DAVID
  *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
  *
@@ -18,6 +19,7 @@
 #include <string>
 #include <algorithm>
 
+#include "View.hxx"
 #include "BlockAdapter.hxx"
 #include "CprAdapter.hxx"
 #include "DiagramAdapter.hxx"
@@ -34,19 +36,18 @@ namespace org_scilab_modules_scicos
 namespace view_scilab
 {
 
-Adapters Adapters::m_instance = Adapters();
+Adapters Adapters::m_instance;
 
 Adapters& Adapters::instance()
 {
     return m_instance;
 }
 
-Adapters::Adapters()
+Adapters::Adapters() : adapters()
 {
     /*
      * Create the supported data types list
      */
-    adapters = adapters_t();
     // we assume that the INVALID_ADAPTER is set at end of the enum
     adapters.reserve(INVALID_ADAPTER);
 
@@ -136,14 +137,21 @@ types::InternalType* Adapters::allocate_view(ScicosID id, kind_t kind)
 {
     Controller controller;
 
-    switch (kind)
+    return allocate_view(controller, controller.getBaseObject(id));
+}
+
+types::InternalType* Adapters::allocate_view(Controller& controller, model::BaseObject* o)
+{
+    switch (o->kind())
     {
         case BLOCK:
-            return new view_scilab::BlockAdapter(controller, controller.getBaseObject<model::Block>(id));
-        case LINK:
-            return new view_scilab::LinkAdapter(controller, controller.getBaseObject<model::Link>(id));
+	        return new view_scilab::BlockAdapter(controller, static_cast<model::Block*>(o));
         case DIAGRAM:
-            return new view_scilab::DiagramAdapter(controller, controller.getBaseObject<model::Diagram>(id));
+	        return new view_scilab::DiagramAdapter(controller, static_cast<model::Diagram*>(o));
+        case ANNOTATION:
+	        return new view_scilab::TextAdapter(controller, static_cast<model::Annotation*>(o));
+        case LINK:
+            return new view_scilab::LinkAdapter(controller, static_cast<model::Link*>(o));
         default:
             return nullptr;
     }
