@@ -34,6 +34,7 @@
 #include "ModelAdapter.hxx"
 #include "LinkAdapter.hxx"
 #include "DiagramAdapter.hxx"
+#include "GraphicsAdapter.hxx"
 
 #include "view_scilab/Adapters.hxx"
 #include "ports_management.hxx"
@@ -79,7 +80,8 @@ types::InternalType* get_with_vec2var(const ModelAdapter& adaptor, const Control
     types::InternalType* res;
     if (!vec2var(prop_content, res))
     {
-        return nullptr;
+        // if invalid data, return a valid value
+        return types::Double::Empty();
     }
 
     return res;
@@ -1178,30 +1180,12 @@ struct label
     {
         model::Block* adaptee = adaptor.getAdaptee();
 
-        ScicosID label;
         std::string description;
-
-        controller.getObjectProperty(adaptee, LABEL, label);
-        if (label != ScicosID())
-        {
-            controller.getObjectProperty(label, ANNOTATION, DESCRIPTION, description);
-        }
-        else
-        {
-            controller.getObjectProperty(adaptee, DESCRIPTION, description);
-        }
+        controller.getObjectProperty(adaptee, DESCRIPTION, description);
 
         types::String* o = new types::String(1, 1);
+        o->set(0, description.data());
 
-        // safety check ; the returned value should always be a valid C / modelica identifier
-        if (isValidCIdentifier(description))
-        {
-            o->set(0, description.data());
-        }
-        else
-        {
-            o->set(0, "");
-        }
         return o;
     }
 
@@ -1226,13 +1210,6 @@ struct label
         std::string description(c_str);
         FREE(c_str);
 
-        // TODO: validate a C/Scilab identifier only
-        //        if (!isValidCIdentifier(label))
-        //        {
-        //            get_or_allocate_logger()->log(LOG_ERROR, _("Wrong value for field %s.%s : Valid C identifier expected.\n"), "model", "label");
-        //            return false;
-        //        }
-
         controller.setObjectProperty(adaptee, DESCRIPTION, description);
         return true;
     }
