@@ -1,7 +1,7 @@
 /*
  *  Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  *  Copyright (C) 2015 - Scilab Enterprises - Calixte DENIZET
- *  Copyright (C) 2017 - Samuel GOUGEON
+ *  Copyright (C) 2017, 2018 - Samuel GOUGEON
  *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
  *
@@ -93,15 +93,21 @@ std::unordered_map<std::wstring, std::wstring> DeprecatedChecker::initDep()
     // TODO: get this list from a conf file
     std::unordered_map<std::wstring, std::wstring> map;
     // Scilab 6.0.x => 6.1.0
+    map.emplace(L"dirname", L"fileparts");
     map.emplace(L"_d", L"_");
     map.emplace(L"dgettext", L"gettext");
+    map.emplace(L"datatipToggle", L"datatipManagerMode");
     map.emplace(L"denom", L".den");
+    map.emplace(L"getPreferencesValue", L"xmlGetValues");
+    map.emplace(L"hypermat", L"zeros|matrix");
     map.emplace(L"lstsize", L"size");
     map.emplace(L"nanmin", L"min");
     map.emplace(L"nanmax", L"max");
     map.emplace(L"numer", L".num");
     map.emplace(L"square", L"replot");
+    map.emplace(L"with_tk", L"with_module('tclsci')");
     map.emplace(L"xgetech", L"gca");
+    map.emplace(L"xinfo", L"gcf().info_message");
 
     // Scilab 5.5.2 => 6.0.0
     map.emplace(L"fort", L"call");
@@ -137,6 +143,7 @@ std::unordered_map<std::wstring, std::wstring> DeprecatedChecker::initDep()
     map.emplace(L"xpause", L"sleep");
     map.emplace(L"curblockc", L"curblock");
     map.emplace(L"extract_help_examples", L"");
+    map.emplace(L"mtlb_mode", L"oldEmptyBehaviour");
 
     map.emplace(L"addf", L"");
     map.emplace(L"subf", L"");
@@ -147,7 +154,7 @@ std::unordered_map<std::wstring, std::wstring> DeprecatedChecker::initDep()
     map.emplace(L"solve", L"");
     map.emplace(L"trianfml", L"");
     map.emplace(L"trisolve", L"");
-    map.emplace(L"block2exp", L"");
+    map.emplace(L"bloc2exp", L"");
 
     map.emplace(L"comp", L"exec");
     map.emplace(L"errcatch", L"");
@@ -185,11 +192,14 @@ std::unordered_map<std::wstring, std::wstring> DeprecatedChecker::initDep()
     map.emplace(L"dft", L"fft");
     map.emplace(L"sscanf", L"msscanf");
     map.emplace(L"fscanf", L"mfscanf");
+    map.emplace(L"printf", L"mprintf");
     map.emplace(L"fprintf", L"mfprintf");
+    map.emplace(L"sprintf", L"msprintf");
     map.emplace(L"demo_message", L"");
     map.emplace(L"demo_mdialog", L"");
     map.emplace(L"draw", L"");
     map.emplace(L"clear_pixmap", L"");
+    map.emplace(L"show_pixmap", L"");
     map.emplace(L"winclose", L"close");
     map.emplace(L"datatipInitStruct", L"");
     map.emplace(L"datatipRedraw", L"");
