@@ -20,6 +20,8 @@
 #include <iterator>
 #include <set>
 #include <cmath>
+#include "alltypes.hxx"
+#include "types_tools.hxx"
 
 #include "BrowseVar.hxx"
 #ifdef _MSC_VER
@@ -43,14 +45,17 @@ extern "C"
 #include "freeArrayOfString.h"
 #include "os_string.h"
 #include "api_scilab.h"
+#include "sci_types.h"
+#include "sciprint.h"
 }
 
 #define N_A             "N/A"
 #define EMPTY_MATRIX    "[ ]"
+#define EMPTY_CELL      "{}"
+#define EMPTY_LIST      "()"
 #define LOCAL_STR       "local"
 #define GLOBAL_STR      "global"
 #define INHERITED_STR   "inherited"
-#define STRUCT_STR      "st"
 #define NEG_INF_STR     "-Inf"
 #define INF_STR         "Inf"
 #define NAN_STR         "NaN"
@@ -68,7 +73,7 @@ using std::string;
 static std::set<string> createScilabDefaultVariablesSet();
 static char * getListName(char * variableName);
 static std::string formatMatrix(int nbRows, int nbCols, double *pdblReal, double *pdblImg);
-static char * valueToDisplay(types::InternalType* pIT, int variableType, int nbRows, int nbCols);
+static char * valueToDisplay(types::InternalType* pIT);
 void OpenBrowseVar()
 {
     BrowseVar::openVariableBrowser(getScilabJavaVM());
@@ -92,10 +97,8 @@ void SetBrowseVarData()
     symbol::Context* ctx = symbol::Context::getInstance();
 
     std::list<symbol::Variable*> lstVars;
-    std::list<symbol::Library*> lstLibs;
 
     iLocalVariablesUsed = ctx->getVarsToVariableBrowser(lstVars);
-    iLocalVariablesUsed += ctx->getLibsToVariableBrowser(lstLibs);
 
     char **pstAllVariableNames = new char*[iLocalVariablesUsed]();
     char **pstAllVariableVisibility = new char*[iLocalVariablesUsed]();
@@ -141,27 +144,36 @@ void SetBrowseVarData()
             pstAllVariableVisibility[i] = os_strdup(LOCAL_STR);
         }
 
-        // type
+        // type with Scilab < 6 compatibility (structs and cells have type 17)
         err = getVarType(NULL, (int*)pIT, &piAllVariableTypes[i]);
-        if (!err.iErr)
-        {
-            piAllVariableBytes[i] = 0;
-            err = getVarDimension(NULL, (int*)pIT, &nbRows, &nbCols);
-        }
 
-        if (err.iErr)
+        if (pIT->isArrayOf() || pIT->isSparse())
         {
-            pstAllVariableSizes[i] = os_strdup(N_A);
+            int nbRows = pIT->getAs<types::GenericType>()->getRows();
+            int nbCols = pIT->getAs<types::GenericType>()->getCols();
+            piAllVariableNbRows[i] = nbRows;
+            piAllVariableNbCols[i] = nbCols;                
+            if (nbRows*nbCols == 0)
+            {
+                pstAllVariableSizes[i] = pIT->isCell() ? os_strdup(EMPTY_CELL) : os_strdup(EMPTY_MATRIX);                
+            }
+            else if (pIT->isArrayOf())
+            {
+                pstAllVariableSizes[i] = valueToDisplay(pIT);
+            }
+            else
+            {
+                std::string sizeString = std::to_string(nbRows) + "x" + std::to_string(nbCols);
+                pstAllVariableSizes[i] =  os_strdup(sizeString.data());
+            }
         }
-        else if (nbRows * nbCols == 0)
+        else if (pIT->isMList() || pIT->isTList() || pIT->isList() )
         {
-            pstAllVariableSizes[i] = os_strdup(EMPTY_MATRIX);
+            pstAllVariableSizes[i] = pIT->getAs<types::List>()->getSize() == 0 ? os_strdup(EMPTY_LIST) : os_strdup(N_A);
         }
         else
         {
-            pstAllVariableSizes[i] = valueToDisplay(pIT, piAllVariableTypes[i], nbRows, nbCols);
-            piAllVariableNbRows[i] = nbRows;
-            piAllVariableNbCols[i] = nbCols;
+            pstAllVariableSizes[i] =  os_strdup(N_A);
         }
 
         if (piAllVariableTypes[i] == sci_ints)
@@ -201,7 +213,13 @@ void SetBrowseVarData()
         }
         else if (pIT->isStruct())
         {
-            pstAllVariableListTypes[i] = os_strdup(STRUCT_STR);
+            piAllVariableTypes[i] = sci_struct;
+            pstAllVariableListTypes[i] = os_strdup("");
+        }
+        else if (pIT->isCell())
+        {
+            piAllVariableTypes[i] = sci_cell;
+            pstAllVariableListTypes[i] = os_strdup("");
         }
         else
         {
@@ -220,36 +238,6 @@ void SetBrowseVarData()
         ++i;
     }
 
-    for (auto lib : lstLibs)
-    {
-        //get top level value
-        symbol::ScopedLibrary* sl = lib->top();
-
-        // get name
-        pstAllVariableNames[i] = wide_string_to_UTF8(lib->getSymbol().getName().data());
-
-        // get visibility
-        if (sl->m_iLevel != iLevel)
-        {
-            pstAllVariableVisibility[i] = os_strdup(INHERITED_STR);
-        }
-        else
-        {
-            pstAllVariableVisibility[i] = os_strdup(LOCAL_STR);
-        }
-        //type
-        piAllVariableTypes[i] = sci_lib;
-
-        piAllVariableBytes[i] = 0;
-        pstAllVariableSizes[i] = os_strdup(N_A);
-        piAllVariableIntegerTypes[i] = -1;
-        pstAllVariableListTypes[i] = os_strdup("");
-        piAllVariableFromUser[i] = FALSE;
-        piAllVariableNbRows[i] = 1;
-        piAllVariableNbCols[i] = 1;
-
-        ++i;
-    }
     // Launch Java Variable Browser through JNI
     BrowseVar::setVariableBrowserData(getScilabJavaVM(),
                                       pstAllVariableNames, iLocalVariablesUsed,
@@ -369,11 +357,13 @@ static char * getListName(char * variableName)
     return tmpChar;
 }
 
-static char * valueToDisplay(types::InternalType* pIT, int variableType, int nbRows, int nbCols)
+static char *valueToDisplay(types::InternalType* pIT)
 {
-    // 4 is the dimension max to which display the content
-    if (nbRows * nbCols <= 4 && variableType == sci_matrix)
-    {
+    types::GenericType *pGT = pIT->getAs<types::GenericType>();
+    int *piDims = pGT->getDimsArray();
+
+    if (pIT->isDouble() && pGT->getDims() < 3 && pGT->getSize() <= 4) {
+        // 4 is the dimension max to which display the content
         types::Double* pD = pIT->getAs<types::Double>();
         // Small double value, display it
         double* pdblReal = nullptr;
@@ -385,16 +375,18 @@ static char * valueToDisplay(types::InternalType* pIT, int variableType, int nbR
             pdblImg = pD->getImg();
         }
 
-
-        return os_strdup(formatMatrix(nbRows, nbCols, pdblReal, pdblImg).c_str());
+        return os_strdup(formatMatrix(piDims[0], piDims[1], pdblReal, pdblImg).c_str());
     }
     else
     {
-        char *sizeStr = NULL;
-        // 11 =strlen("2147483647")+1 (1 for security)
-        sizeStr = (char *)MALLOC((11 + 11 + 1 + 1) * sizeof(char));
-        sprintf(sizeStr, "%dx%d", nbRows, nbCols);
-        return sizeStr;
+        std::string sizeStr = std::to_string(piDims[0]);
+        for (int i = 1; i < pGT->getDims(); i++)
+        {
+            sizeStr.append("x");
+            sizeStr.append(std::to_string(piDims[i]));
+        }
+
+        return os_strdup(sizeStr.data());
     }
 }
 
@@ -431,58 +423,58 @@ std::string formatMatrix(int nbRows, int nbCols, double *pdblReal, double *pdblI
     if (nbRows * nbCols == 1)
     {
         std::ostringstream os;
-        std::string formated = addDouble(pdblReal[0]);
+        std::string formatted = addDouble(pdblReal[0]);
         if (pdblImg)
         {
             double img = pdblImg[0];
             if (img > 0)
             {
-                formated += PLUS_STR;
+                formatted += PLUS_STR;
             }
             else
             {
-                formated += MINUS_STR;
+                formatted += MINUS_STR;
             }
-            formated += addDouble(std::fabs(img));
-            formated += I_STR;
+            formatted += addDouble(std::fabs(img));
+            formatted += I_STR;
         }
-        return formated;
+        return formatted;
     }
 
-    std::string formated = LBRACKET_STR;
+    std::string formatted = LBRACKET_STR;
     for (j = 0 ; j < nbRows ; j++)
     {
         for (i = 0 ; i < nbCols ; i++)
         {
-            /* Display the formated matrix ... the way the user
+            /* Display the formatted matrix ... the way the user
              * expect */
-            formated += addDouble(pdblReal[i * nbRows + j]);
+            formatted += addDouble(pdblReal[i * nbRows + j]);
             if (pdblImg)
             {
                 double img = pdblImg[i * nbRows + j];
                 if (img > 0)
                 {
-                    formated += PLUS_STR;
+                    formatted += PLUS_STR;
                 }
                 else
                 {
-                    formated += MINUS_STR;
+                    formatted += MINUS_STR;
                 }
 
-                formated += addDouble(std::fabs(img));
-                formated += I_STR;
+                formatted += addDouble(std::fabs(img));
+                formatted += I_STR;
             }
 
 
             if (i + 1 != nbCols) // Not the last element of the matrix
             {
-                formated += COMMA_STR;
+                formatted += COMMA_STR;
             }
         }
         if (j + 1 != nbRows) // Not the last line of the matrix
         {
-            formated += SEMICOLON_STR;
+            formatted += SEMICOLON_STR;
         }
     }
-    return formated + "]";
+    return formatted + "]";
 }
