@@ -78,7 +78,6 @@ import org.scilab.modules.ui_data.actions.SparseBoolFilteringAction;
 import org.scilab.modules.ui_data.actions.SparseFilteringAction;
 import org.scilab.modules.ui_data.actions.StringFilteringAction;
 import org.scilab.modules.ui_data.actions.TListFilteringAction;
-import org.scilab.modules.ui_data.actions.UncompiledFunctionFilteringAction;
 import org.scilab.modules.ui_data.datatable.SwingTableModel;
 import org.scilab.modules.ui_data.utils.UiDataMessages;
 import org.scilab.modules.ui_data.variableeditor.actions.ExportToCsvAction;
@@ -116,7 +115,6 @@ public final class SwingScilabVariableBrowser extends SwingScilabDockablePanel i
     private CheckBoxMenuItem filterIntegerCheckBox;
     private CheckBoxMenuItem filterGraphicHandlesCheckBox;
     private CheckBoxMenuItem filterStringCheckBox;
-    private CheckBoxMenuItem filterUncompiledFuncCheckBox;
     private CheckBoxMenuItem filtercompiledFuncCheckBox;
     private CheckBoxMenuItem filterFunctionLibCheckBox;
     private CheckBoxMenuItem filterListCheckBox;
@@ -493,9 +491,6 @@ public final class SwingScilabVariableBrowser extends SwingScilabDockablePanel i
         filterGraphicHandlesCheckBox.setChecked(true);
         filterMenu.add(filterGraphicHandlesCheckBox);
 
-        filterUncompiledFuncCheckBox = UncompiledFunctionFilteringAction.createCheckBoxMenu();
-        filterMenu.add(filterUncompiledFuncCheckBox);
-
         filtercompiledFuncCheckBox = CompiledFunctionFilteringAction.createCheckBoxMenu();
         filterMenu.add(filtercompiledFuncCheckBox);
 
@@ -586,10 +581,6 @@ public final class SwingScilabVariableBrowser extends SwingScilabDockablePanel i
             filteredValues.add(ScilabTypeEnum.sci_handles);
         }
 
-        if (!filterUncompiledFuncCheckBox.isChecked()) {
-            filteredValues.add(ScilabTypeEnum.sci_u_function);
-        }
-
         if (!filtercompiledFuncCheckBox.isChecked()) {
             filteredValues.add(ScilabTypeEnum.sci_c_function);
         }
