@@ -4,7 +4,7 @@
  * Copyright (C) 2009-2010 - DIGITEO - Clement DAVID
  * Copyright (C) 2011-2017 - Scilab Enterprises - Clement DAVID
  * Copyright (C) 2015 - Marcos Cardinot
- * Copyright (C) 2017 - ESI Group - Clement DAVID
+ * Copyright (C) 2017-2019 - ESI Group - Clement DAVID
  *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
  *
@@ -1938,6 +1938,28 @@ public class XcosDiagram extends ScilabGraph {
         }
     }
 
+    /**
+     * @return the title of the current diagram (root diagram or super block)
+     */
+    @Override
+    public String getTitle() {
+        JavaController controller = new JavaController();
+        String[] property = {""};
+
+        if (getKind() == Kind.DIAGRAM) {
+            controller.getObjectProperty(getUID(), getKind(), ObjectProperties.TITLE, property);
+        } else { // Kind.BLOCK
+            // use the one-line description
+            controller.getObjectProperty(getUID(), getKind(), ObjectProperties.DESCRIPTION, property);
+        }
+
+        if (property[0].isEmpty()) {
+            return super.getTitle();
+        } else {
+            return property[0];
+        }
+    }
+
     /**
      * Set the title of the diagram
      *
@@ -2402,7 +2424,7 @@ public class XcosDiagram extends ScilabGraph {
             // read the structure
             result = handler.readContext();
         } catch (final InterpreterException e) {
-            info("Unable to evaluate the contexte");
+            info("Unable to evaluate the context");
             e.printStackTrace();
         } finally {
             handler.release();
